@@ -15,7 +15,8 @@ class MissingFile(PkgcoreException):
 
     def __init__(self, filename, setting):
         super().__init__(
-            f"setting {setting} points at {filename!r}, which doesn't exist.")
+            f"setting {setting} points at {filename!r}, which doesn't exist."
+        )
         self.file, self.setting = filename, setting
 
 
@@ -23,7 +24,7 @@ class Failure(PkgcoreException):
     """Generic domain failure."""
 
     def __init__(self, text):
-        super().__init__(f'domain failure: {text}')
+        super().__init__(f"domain failure: {text}")
         self.text = text
 
 
@@ -39,26 +40,35 @@ class domain:
     def triggers(self):
         return tuple(self._triggers)
 
-    def pkg_operations(self, pkg, observer=None):
+    def get_pkg_operations(self, pkg, observer=None):
+        """Get the manager of package operations for the given package
+
+        If you wish to modify a package- invoke setup, install, etc- this is what's responsible
+        for giving you a common interface despite the format implementation varying.
+        """
         domain = self.get_package_domain(pkg)
         return pkg.operations(domain, observer=observer)
 
     def build_pkg(self, pkg, observer=None, failed=False, clean=True, **kwargs):
         domain = self.get_package_domain(pkg)
-        return domain.pkg_operations(pkg, observer=observer).build(
-            observer=observer, failed=failed, clean=clean, **kwargs)
+        return domain.get_pkg_operations(pkg, observer=observer).build(
+            observer=observer, failed=failed, clean=clean, **kwargs
+        )
 
     def install_pkg(self, newpkg, observer):
         domain = self.get_package_domain(newpkg)
         return domain_ops.install(
-            domain, domain.all_installed_repos, newpkg, observer, domain.root)
+            domain, domain.all_installed_repos, newpkg, observer, domain.root
+        )
 
     def uninstall_pkg(self, pkg, observer):
         domain = self.get_package_domain(pkg)
         return domain_ops.uninstall(
-            domain, domain.all_installed_repos, pkg, observer, domain.root)
+            domain, domain.all_installed_repos, pkg, observer, domain.root
+        )
 
     def replace_pkg(self, oldpkg, newpkg, observer):
         domain = self.get_package_domain(newpkg)
         return domain_ops.replace(
-            domain, domain.all_installed_repos, oldpkg, newpkg, observer, domain.root)
+            domain, domain.all_installed_repos, oldpkg, newpkg, observer, domain.root
+        )
