@@ -4,7 +4,8 @@ Converts portage config files into :obj:`pkgcore.config` form.
 """
 
 __all__ = (
-    'PortageConfig', 'SecurityUpgradesViaProfile',
+    "PortageConfig",
+    "SecurityUpgradesViaProfile",
 )
 
 import configparser
@@ -16,7 +17,7 @@ from collections import OrderedDict
 from snakeoil.bash import read_bash_dict
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
 from snakeoil.mappings import DictMixin, ImmutableDict
-from snakeoil.osutils import access, listdir_files, pjoin
+from snakeoil.osutils import listdir_files, pjoin
 
 from .. import const
 from .. import exceptions as base_errors
@@ -34,14 +35,16 @@ from .repository import errors as repo_errors
 
 def my_convert_hybrid(manager, val, arg_type):
     """Modified convert_hybrid using a sequence of strings for section_refs."""
-    if arg_type.startswith('refs:'):
-        subtype = 'ref:' + arg_type.split(':', 1)[1]
+    if arg_type.startswith("refs:"):
+        subtype = "ref:" + arg_type.split(":", 1)[1]
         return [basics.LazyNamedSectionRef(manager, subtype, name) for name in val]
     return basics.convert_hybrid(manager, val, arg_type)
 
 
-@configurable({'ebuild_repo': 'ref:repo', 'vdb': 'ref:repo',
-               'profile': 'ref:profile'}, typename='pkgset')
+@configurable(
+    {"ebuild_repo": "ref:repo", "vdb": "ref:repo", "profile": "ref:profile"},
+    typename="pkgset",
+)
 def SecurityUpgradesViaProfile(ebuild_repo, vdb, profile):
     """generate a GLSA vuln. pkgset limited by profile
 
@@ -107,12 +110,12 @@ class PortageConfig(DictMixin):
             dict: config settings
         """
         self._config = {}
-        stubconfig = pjoin(const.DATA_PATH, 'stubconfig')
+        stubconfig = pjoin(const.DATA_PATH, "stubconfig")
 
         if location is None:
             path = os.path.abspath(sys.prefix)
             while (parent := os.path.dirname(path)) != path:
-                config_root = pjoin(parent, 'etc/portage')
+                config_root = pjoin(parent, "etc/portage")
                 if os.path.exists(config_root):
                     location = config_root
                     break
@@ -123,7 +126,7 @@ class PortageConfig(DictMixin):
 
         # override profile when using stub config
         if location == stubconfig:
-            profile_override = pjoin(const.DATA_PATH, 'stubrepo/profiles/default')
+            profile_override = pjoin(const.DATA_PATH, "stubrepo/profiles/default")
 
         self.dir = location
 
@@ -135,69 +138,89 @@ class PortageConfig(DictMixin):
 
         make_conf = {}
         try:
-            self.load_make_conf(make_conf, pjoin(const.CONFIG_PATH, 'make.globals'))
+            self.load_make_conf(make_conf, pjoin(const.CONFIG_PATH, "make.globals"))
         except IGNORED_EXCEPTIONS:
             raise
         except Exception as e:
             raise config_errors.ParsingError("failed to load make.globals") from e
         self.load_make_conf(
-            make_conf, pjoin(self.dir, 'make.conf'), required=False,
-            allow_sourcing=True, incrementals=True)
+            make_conf,
+            pjoin(self.dir, "make.conf"),
+            required=False,
+            allow_sourcing=True,
+            incrementals=True,
+        )
 
-        self.root = kwargs.pop('root', make_conf.get("ROOT", "/"))
+        self.root = kwargs.pop("root", make_conf.get("ROOT", "/"))
         gentoo_mirrors = [
-            x.rstrip("/") + "/distfiles" for x in make_conf.pop("GENTOO_MIRRORS", "").split()]
+            x.rstrip("/") + "/distfiles"
+            for x in make_conf.pop("GENTOO_MIRRORS", "").split()
+        ]
 
         self.features = frozenset(
-            optimize_incrementals(make_conf.get('FEATURES', '').split()))
+            optimize_incrementals(make_conf.get("FEATURES", "").split())
+        )
 
         self._add_sets()
         self._add_profile(profile_override)
 
-        self['vdb'] = basics.AutoConfigSection({
-            'class': 'pkgcore.vdb.ondisk.tree',
-            'location': pjoin(self.root, 'var', 'db', 'pkg'),
-            'cache_location': '/var/cache/edb/dep/var/db/pkg',
-        })
+        self["vdb"] = basics.AutoConfigSection(
+            {
+                "class": "pkgcore.vdb.ondisk.tree",
+                "location": pjoin(self.root, "var", "db", "pkg"),
+                "cache_location": "/var/cache/edb/dep/var/db/pkg",
+            }
+        )
 
         try:
             repos_conf_defaults, repos_conf = self.load_repos_conf(
-                pjoin(self.dir, 'repos.conf'))
+                pjoin(self.dir, "repos.conf")
+            )
         except config_errors.ParsingError as e:
-            if not getattr(getattr(e, 'exc', None), 'errno', None) == errno.ENOENT:
+            if not getattr(getattr(e, "exc", None), "errno", None) == errno.ENOENT:
                 raise
             try:
                 # fallback to defaults provided by pkgcore
                 repos_conf_defaults, repos_conf = self.load_repos_conf(
-                    pjoin(const.CONFIG_PATH, 'repos.conf'))
+                    pjoin(const.CONFIG_PATH, "repos.conf")
+                )
             except IGNORED_EXCEPTIONS:
                 raise
             except Exception as e:
-                raise config_errors.ParsingError('failed to find a usable repos.conf') from e
+                raise config_errors.ParsingError(
+                    "failed to find a usable repos.conf"
+                ) from e
 
-        self['ebuild-repo-common'] = basics.AutoConfigSection({
-            'class': 'pkgcore.ebuild.repository.tree',
-            'default_mirrors': gentoo_mirrors,
-            'inherit-only': True,
-        })
+        self["ebuild-repo-common"] = basics.AutoConfigSection(
+            {
+                "class": "pkgcore.ebuild.repository.tree",
+                "default_mirrors": gentoo_mirrors,
+                "inherit-only": True,
+            }
+        )
 
         repo_map = {}
         repos = []
 
         for repo_name, repo_opts in list(repos_conf.items()):
-            repo_cls = repo_opts.pop('repo-type')
+            repo_cls = repo_opts.pop("repo-type")
             try:
                 repo = repo_cls(
-                    self, repo_name=repo_name, repo_opts=repo_opts,
-                    repo_map=repo_map, defaults=repos_conf_defaults)
+                    self,
+                    repo_name=repo_name,
+                    repo_opts=repo_opts,
+                    repo_map=repo_map,
+                    defaults=repos_conf_defaults,
+                )
             except repo_errors.UnsupportedRepo as e:
                 logger.warning(
-                    f'skipping {repo_name!r} repo: unsupported EAPI {str(e.repo.eapi)!r}')
+                    f"skipping {repo_name!r} repo: unsupported EAPI {str(e.repo.eapi)!r}"
+                )
                 del repos_conf[repo_name]
                 continue
 
             # only register existent repos
-            if os.path.exists(repo_opts['location']):
+            if os.path.exists(repo_opts["location"]):
                 self[repo_name] = basics.AutoConfigSection(repo)
                 repos.append(repo_name)
 
@@ -207,36 +230,44 @@ class PortageConfig(DictMixin):
 
         self._make_repo_syncers(repos_conf, make_conf)
         if repos:
-            self['repo-stack'] = basics.FakeIncrementalDictConfigSection(
-                my_convert_hybrid, {
-                    'class': 'pkgcore.repository.multiplex.config_tree',
-                    'repos': tuple(repos)})
+            self["repo-stack"] = basics.FakeIncrementalDictConfigSection(
+                my_convert_hybrid,
+                {
+                    "class": "pkgcore.repository.multiplex.config_tree",
+                    "repos": tuple(repos),
+                },
+            )
 
-            self['vuln'] = basics.AutoConfigSection({
-                'class': SecurityUpgradesViaProfile,
-                'ebuild_repo': 'repo-stack',
-                'vdb': 'vdb',
-                'profile': 'profile',
-            })
+            self["vuln"] = basics.AutoConfigSection(
+                {
+                    "class": SecurityUpgradesViaProfile,
+                    "ebuild_repo": "repo-stack",
+                    "vdb": "vdb",
+                    "profile": "profile",
+                }
+            )
 
         # check if package building was forced on by the user
-        forced_buildpkg = kwargs.pop('buildpkg', False)
+        forced_buildpkg = kwargs.pop("buildpkg", False)
         if forced_buildpkg:
-            make_conf['FEATURES'] += ' buildpkg'
+            make_conf["FEATURES"] += " buildpkg"
 
         # finally... domain.
-        make_conf.update({
-            'class': 'pkgcore.ebuild.domain.domain',
-            'repos': tuple(repos),
-            'default': True,
-            'vdb': ('vdb',),
-            'profile': 'profile',
-            'root': self.root,
-            'config_dir': self.dir,
-        })
+        make_conf.update(
+            {
+                "class": "pkgcore.ebuild.domain.domain",
+                "repos": tuple(repos),
+                "default": True,
+                "vdb": ("vdb",),
+                "profile": "profile",
+                "root": self.root,
+                "config_dir": self.dir,
+            }
+        )
 
-        self['livefs'] = basics.FakeIncrementalDictConfigSection(
-            my_convert_hybrid, make_conf)
+        self["livefs"] = basics.FakeIncrementalDictConfigSection(
+            my_convert_hybrid, make_conf
+        )
 
     def __setitem__(self, key, value):
         self._config[key] = value
@@ -251,8 +282,14 @@ class PortageConfig(DictMixin):
         return iter(self._config.keys())
 
     @staticmethod
-    def load_make_conf(vars_dict, path, allow_sourcing=False, required=True,
-                       allow_recurse=True, incrementals=False):
+    def load_make_conf(
+        vars_dict,
+        path,
+        allow_sourcing=False,
+        required=True,
+        allow_recurse=True,
+        incrementals=False,
+    ):
         """parse make.conf files
 
         Args:
@@ -261,24 +298,31 @@ class PortageConfig(DictMixin):
                 directory, if a directory is passed all the non-hidden files within
                 that directory are parsed in alphabetical order.
         """
-        sourcing_command = 'source' if allow_sourcing else None
+        sourcing_command = "source" if allow_sourcing else None
 
         if allow_recurse:
             files = sorted_scan(
-                os.path.realpath(path), follow_symlinks=True, nonexistent=True,
-                hidden=False, backup=False)
+                os.path.realpath(path),
+                follow_symlinks=True,
+                nonexistent=True,
+                hidden=False,
+                backup=False,
+            )
         else:
             files = (path,)
 
         for fp in files:
             try:
                 new_vars = read_bash_dict(
-                    fp, vars_dict=vars_dict, sourcing_command=sourcing_command)
+                    fp, vars_dict=vars_dict, sourcing_command=sourcing_command
+                )
             except PermissionError as e:
                 raise base_errors.PermissionDenied(fp, write=False) from e
             except EnvironmentError as e:
                 if e.errno != errno.ENOENT or required:
-                    raise config_errors.ParsingError(f"parsing {fp!r}", exception=e) from e
+                    raise config_errors.ParsingError(
+                        f"parsing {fp!r}", exception=e
+                    ) from e
                 return
 
             if incrementals:
@@ -307,60 +351,77 @@ class PortageConfig(DictMixin):
         parser = ParseConfig()
 
         for fp in sorted_scan(
-                os.path.realpath(path), follow_symlinks=True, nonexistent=True,
-                hidden=False, backup=False):
+            os.path.realpath(path),
+            follow_symlinks=True,
+            nonexistent=True,
+            hidden=False,
+            backup=False,
+        ):
+            had_repo_conf = False
             try:
                 with open(fp) as f:
+                    had_repo_conf = True
                     defaults, repo_confs = parser.parse_file(f)
             except PermissionError as e:
                 raise base_errors.PermissionDenied(fp, write=False) from e
             except EnvironmentError as e:
                 raise config_errors.ParsingError(f"parsing {fp!r}", exception=e) from e
             except configparser.Error as e:
-                raise config_errors.ParsingError(f"repos.conf: {fp!r}", exception=e) from e
+                raise config_errors.ParsingError(
+                    f"repos.conf: {fp!r}", exception=e
+                ) from e
 
             if defaults and main_defaults:
-                logger.warning(f"repos.conf: parsing {fp!r}: overriding DEFAULT section")
+                logger.warning(
+                    f"repos.conf: parsing {fp!r}: overriding DEFAULT section"
+                )
             main_defaults.update(defaults)
 
-            if not repo_confs:
-                logger.warning(f"repos.conf: parsing {fp!r}: file is empty")
+            if not had_repo_conf and not repo_confs:
+                logger.warning(
+                    "repos.conf: not found, but should exist for modern support"
+                )
 
             for name, repo_conf in repo_confs.items():
                 if name in repos:
-                    logger.warning(f"repos.conf: parsing {fp!r}: overriding {name!r} repo")
+                    logger.warning(
+                        f"repos.conf: parsing {fp!r}: overriding {name!r} repo"
+                    )
 
                 # ignore repo if location is unset
-                location = repo_conf.get('location', None)
+                location = repo_conf.get("location", None)
                 if location is None:
                     logger.warning(
                         f"repos.conf: parsing {fp!r}: "
-                        f"{name!r} repo missing location setting, ignoring repo")
+                        f"{name!r} repo missing location setting, ignoring repo"
+                    )
                     continue
                 location = os.path.expanduser(location)
                 if os.path.isabs(location):
-                    repo_conf['location'] = location
+                    repo_conf["location"] = location
                 else:
                     # support relative paths based on where repos.conf is located
-                    repo_conf['location'] = os.path.abspath(
-                        pjoin(os.path.dirname(path), location))
+                    repo_conf["location"] = os.path.abspath(
+                        pjoin(os.path.dirname(path), location)
+                    )
 
                 # repo type defaults to ebuild for compat with portage
-                repo_type = repo_conf.get('repo-type', 'ebuild-v1')
+                repo_type = repo_conf.get("repo-type", "ebuild-v1")
                 try:
-                    repo_conf['repo-type'] = cls._supported_repo_types[repo_type]
+                    repo_conf["repo-type"] = cls._supported_repo_types[repo_type]
                 except KeyError:
                     logger.warning(
                         f"repos.conf: parsing {fp!r}: "
                         f"{name!r} repo has unsupported repo-type {repo_type!r}, "
-                        "ignoring repo")
+                        "ignoring repo"
+                    )
                     continue
 
                 # Priority defaults to zero if unset or invalid for ebuild repos
                 # while binpkg repos have the lowest priority by default.
-                priority = repo_conf.get('priority', None)
+                priority = repo_conf.get("priority", None)
                 if priority is None:
-                    if repo_type.startswith('binpkg'):
+                    if repo_type.startswith("binpkg"):
                         priority = -10000
                     else:
                         priority = 0
@@ -370,88 +431,96 @@ class PortageConfig(DictMixin):
                 except ValueError:
                     logger.warning(
                         f"repos.conf: parsing {fp!r}: {name!r} repo has invalid priority "
-                        f"setting: {priority!r} (defaulting to 0)")
+                        f"setting: {priority!r} (defaulting to 0)"
+                    )
                     priority = 0
                 finally:
-                    repo_conf['priority'] = priority
+                    repo_conf["priority"] = priority
 
                 # register repo
                 repos[name] = repo_conf
 
         if repos:
             # the default repo is gentoo if unset and gentoo exists
-            default_repo = main_defaults.get('main-repo', 'gentoo')
+            default_repo = main_defaults.get("main-repo", "gentoo")
             if default_repo not in repos:
                 raise config_errors.UserConfigError(
-                    f"repos.conf: default repo {default_repo!r} is undefined or invalid")
+                    f"repos.conf: default repo {default_repo!r} is undefined or invalid"
+                )
 
-            if 'main-repo' not in main_defaults:
-                main_defaults['main-repo'] = default_repo
+            if "main-repo" not in main_defaults:
+                main_defaults["main-repo"] = default_repo
 
             # the default repo has a low priority if unset or zero
-            if repos[default_repo]['priority'] == 0:
-                repos[default_repo]['priority'] = -1000
+            if repos[default_repo]["priority"] == 0:
+                repos[default_repo]["priority"] = -1000
 
         # sort repos via priority, in this case high values map to high priorities
         repos = OrderedDict(
-            (k, v) for k, v in
-            sorted(repos.items(), key=lambda d: d[1]['priority'], reverse=True))
+            (k, v)
+            for k, v in sorted(
+                repos.items(), key=lambda d: d[1]["priority"], reverse=True
+            )
+        )
 
         return main_defaults, repos
 
     def _make_repo_syncers(self, repos_conf, make_conf, allow_timestamps=True):
         """generate syncing configs for known repos"""
         rsync_opts = None
-        usersync = 'usersync' in self.features
+        usersync = "usersync" in self.features
 
         for repo_name, repo_opts in repos_conf.items():
-            d = {'basedir': repo_opts['location'], 'usersync': usersync}
+            d = {"basedir": repo_opts["location"], "usersync": usersync}
 
-            sync_type = repo_opts.get('sync-type', None)
-            sync_uri = repo_opts.get('sync-uri', None)
+            sync_type = repo_opts.get("sync-type", None)
+            sync_uri = repo_opts.get("sync-uri", None)
 
             if sync_uri:
                 # prefix non-native protocols
-                if (sync_type is not None and not sync_uri.startswith(sync_type)):
-                    sync_uri = f'{sync_type}+{sync_uri}'
+                if sync_type is not None and not sync_uri.startswith(sync_type):
+                    sync_uri = f"{sync_type}+{sync_uri}"
 
-                d['uri'] = sync_uri
-                d['opts'] = repo_opts.get('sync-opts', '')
+                d["uri"] = sync_uri
+                d["opts"] = repo_opts.get("sync-opts", "")
 
-                if sync_type == 'rsync':
+                if sync_type == "rsync":
                     if rsync_opts is None:
                         # various make.conf options used by rsync-based syncers
                         rsync_opts = self._isolate_rsync_opts(make_conf)
                     d.update(rsync_opts)
                     if allow_timestamps:
-                        d['class'] = 'pkgcore.sync.rsync.rsync_timestamp_syncer'
+                        d["class"] = "pkgcore.sync.rsync.rsync_timestamp_syncer"
                     else:
-                        d['class'] = 'pkgcore.sync.rsync.rsync_syncer'
+                        d["class"] = "pkgcore.sync.rsync.rsync_syncer"
                 else:
-                    d['class'] = 'pkgcore.sync.base.GenericSyncer'
+                    d["class"] = "pkgcore.sync.base.GenericSyncer"
             elif sync_uri is None:
                 # try to autodetect syncing mechanism if sync-uri is missing
-                d['class'] = 'pkgcore.sync.base.AutodetectSyncer'
+                d["class"] = "pkgcore.sync.base.AutodetectSyncer"
             else:
                 # disable syncing if sync-uri is explicitly unset
-                d['class'] = 'pkgcore.sync.base.DisabledSync'
+                d["class"] = "pkgcore.sync.base.DisabledSync"
 
-            name = 'sync:' + repo_name
+            name = "sync:" + repo_name
             self[name] = basics.AutoConfigSection(d)
 
     def _add_sets(self):
-        self["world"] = basics.AutoConfigSection({
-            "class": "pkgcore.pkgsets.filelist.WorldFile",
-            "location": pjoin(self.root, econst.WORLD_FILE.lstrip('/'))})
-        self["system"] = basics.AutoConfigSection({
-            "class": "pkgcore.pkgsets.system.SystemSet",
-            "profile": "profile"})
-        self["installed"] = basics.AutoConfigSection({
-            "class": "pkgcore.pkgsets.installed.Installed",
-            "vdb": "vdb"})
-        self["versioned-installed"] = basics.AutoConfigSection({
-            "class": "pkgcore.pkgsets.installed.VersionedInstalled",
-            "vdb": "vdb"})
+        self["world"] = basics.AutoConfigSection(
+            {
+                "class": "pkgcore.pkgsets.filelist.WorldFile",
+                "location": pjoin(self.root, econst.WORLD_FILE.lstrip("/")),
+            }
+        )
+        self["system"] = basics.AutoConfigSection(
+            {"class": "pkgcore.pkgsets.system.SystemSet", "profile": "profile"}
+        )
+        self["installed"] = basics.AutoConfigSection(
+            {"class": "pkgcore.pkgsets.installed.Installed", "vdb": "vdb"}
+        )
+        self["versioned-installed"] = basics.AutoConfigSection(
+            {"class": "pkgcore.pkgsets.installed.VersionedInstalled", "vdb": "vdb"}
+        )
 
         set_fp = pjoin(self.dir, "sets")
         try:
@@ -461,28 +530,36 @@ class PortageConfig(DictMixin):
                 if setname in ("system", "world"):
                     logger.warning(
                         "user defined set %r is disallowed; ignoring",
-                        pjoin(set_fp, setname))
+                        pjoin(set_fp, setname),
+                    )
                     continue
-                self[setname] = basics.AutoConfigSection({
-                    "class": "pkgcore.pkgsets.filelist.FileList",
-                    "location": pjoin(set_fp, setname)})
+                self[setname] = basics.AutoConfigSection(
+                    {
+                        "class": "pkgcore.pkgsets.filelist.FileList",
+                        "location": pjoin(set_fp, setname),
+                    }
+                )
         except FileNotFoundError:
             pass
 
     def _find_profile_path(self, profile_override):
         if profile_override is None:
-            make_profile = pjoin(self.dir, 'make.profile')
+            make_profile = pjoin(self.dir, "make.profile")
             if not os.path.islink(make_profile):
-                raise config_errors.UserConfigError(f'invalid symlink: {make_profile!r}')
+                raise config_errors.UserConfigError(
+                    f"invalid symlink: {make_profile!r}"
+                )
             path = os.path.realpath(make_profile)
         else:
             path = os.path.realpath(profile_override)
 
         if not os.path.exists(path):
             if profile_override is None:
-                raise config_errors.UserConfigError(f'broken symlink: {make_profile!r}')
+                raise config_errors.UserConfigError(f"broken symlink: {make_profile!r}")
             else:
-                raise config_errors.UserConfigError(f'nonexistent profile: {profile_override!r}')
+                raise config_errors.UserConfigError(
+                    f"nonexistent profile: {profile_override!r}"
+                )
         return path
 
     def _add_profile(self, profile_override=None):
@@ -490,23 +567,28 @@ class PortageConfig(DictMixin):
         paths = profiles.OnDiskProfile.split_abspath(profile)
         if paths is None:
             raise config_errors.UserConfigError(
-                '%r expands to %r, but no profile detected' %
-                (pjoin(self.dir, 'make.profile'), profile))
+                "%r expands to %r, but no profile detected"
+                % (pjoin(self.dir, "make.profile"), profile)
+            )
 
-        user_profile_path = pjoin(self.dir, 'profile')
+        user_profile_path = pjoin(self.dir, "profile")
         if os.path.isdir(user_profile_path):
-            self["profile"] = basics.AutoConfigSection({
-                "class": "pkgcore.ebuild.profiles.UserProfile",
-                "parent_path": paths[0],
-                "parent_profile": paths[1],
-                "user_path": user_profile_path,
-            })
+            self["profile"] = basics.AutoConfigSection(
+                {
+                    "class": "pkgcore.ebuild.profiles.UserProfile",
+                    "parent_path": paths[0],
+                    "parent_profile": paths[1],
+                    "user_path": user_profile_path,
+                }
+            )
         else:
-            self["profile"] = basics.AutoConfigSection({
-                "class": "pkgcore.ebuild.profiles.OnDiskProfile",
-                "basepath": paths[0],
-                "profile": paths[1],
-            })
+            self["profile"] = basics.AutoConfigSection(
+                {
+                    "class": "pkgcore.ebuild.profiles.OnDiskProfile",
+                    "basepath": paths[0],
+                    "profile": paths[1],
+                }
+            )
 
     def _isolate_rsync_opts(self, options):
         """
@@ -517,31 +599,31 @@ class PortageConfig(DictMixin):
         opts = []
         extra_opts = []
 
-        opts.extend(options.pop('PORTAGE_RSYNC_OPTS', '').split())
-        extra_opts.extend(options.pop('PORTAGE_RSYNC_EXTRA_OPTS', '').split())
+        opts.extend(options.pop("PORTAGE_RSYNC_OPTS", "").split())
+        extra_opts.extend(options.pop("PORTAGE_RSYNC_EXTRA_OPTS", "").split())
 
-        timeout = options.pop('PORTAGE_RSYNC_INITIAL_TIMEOUT', None)
+        timeout = options.pop("PORTAGE_RSYNC_INITIAL_TIMEOUT", None)
         if timeout is not None:
-            base['conn_timeout'] = timeout
+            base["conn_timeout"] = timeout
 
-        retries = options.pop('PORTAGE_RSYNC_RETRIES', None)
+        retries = options.pop("PORTAGE_RSYNC_RETRIES", None)
         if retries is not None:
             try:
                 retries = int(retries)
                 if retries < 0:
                     retries = 10000
-                base['retries'] = str(retries)
+                base["retries"] = str(retries)
             except ValueError:
                 pass
 
-        proxy = options.pop('RSYNC_PROXY', None)
+        proxy = options.pop("RSYNC_PROXY", None)
         if proxy is not None:
-            base['proxy'] = proxy.strip()
+            base["proxy"] = proxy.strip()
 
         if opts:
-            base['opts'] = tuple(opts)
+            base["opts"] = tuple(opts)
         if extra_opts:
-            base['extra_opts'] = tuple(extra_opts)
+            base["extra_opts"] = tuple(extra_opts)
 
         return base
 
@@ -549,40 +631,44 @@ class PortageConfig(DictMixin):
         """Configure repo cache."""
         # Use md5 cache if it exists or the option is selected, otherwise default
         # to the old flat hash format in /var/cache/edb/dep/*.
-        if (os.path.exists(pjoin(repo_path, 'metadata', 'md5-cache')) or
-                cache_format == 'md5-dict'):
-            kls = 'pkgcore.cache.flat_hash.md5_cache'
-            cache_parent_dir = pjoin(repo_path, 'metadata', 'md5-cache')
+        if (
+            os.path.exists(pjoin(repo_path, "metadata", "md5-cache"))
+            or cache_format == "md5-dict"
+        ):
+            kls = "pkgcore.cache.flat_hash.md5_cache"
+            cache_parent_dir = pjoin(repo_path, "metadata", "md5-cache")
         else:
-            kls = 'pkgcore.cache.flat_hash.database'
-            repo_path = pjoin('/var/cache/edb/dep', repo_path.lstrip('/'))
+            kls = "pkgcore.cache.flat_hash.database"
+            repo_path = pjoin("/var/cache/edb/dep", repo_path.lstrip("/"))
             cache_parent_dir = repo_path
 
         while not os.path.exists(cache_parent_dir):
             cache_parent_dir = os.path.dirname(cache_parent_dir)
-        readonly = (not access(cache_parent_dir, os.W_OK | os.X_OK))
+        readonly = not os.access(cache_parent_dir, os.W_OK | os.X_OK)
 
-        return basics.AutoConfigSection({
-            'class': kls,
-            'location': repo_path,
-            'readonly': readonly
-        })
+        return basics.AutoConfigSection(
+            {"class": kls, "location": repo_path, "readonly": readonly}
+        )
 
     def _register_repo_type(supported_repo_types):
         """Decorator to register supported repo types."""
+
         def _wrap_func(func):
             def wrapped(*args, **kwargs):
                 return func(*args, **kwargs)
-            name = func.__name__[6:].replace('_', '-')
+
+            name = func.__name__[6:].replace("_", "-")
             supported_repo_types[name] = func
             return wrapped
+
         return _wrap_func
 
     @_register_repo_type(_supported_repo_types)
-    def _repo_ebuild_v1(self, repo_name, repo_opts, repo_map,
-                        defaults, repo_obj=None, repo_dict=None):
+    def _repo_ebuild_v1(
+        self, repo_name, repo_opts, repo_map, defaults, repo_obj=None, repo_dict=None
+    ):
         """Create ebuild repo v1 configuration."""
-        repo_path = repo_opts['location']
+        repo_path = repo_opts["location"]
 
         # XXX: Hack for portage-2 profile format support.
         if repo_obj is None:
@@ -591,57 +677,59 @@ class PortageConfig(DictMixin):
 
         # repo configs
         repo_conf = {
-            'class': 'pkgcore.ebuild.repo_objs.RepoConfig',
-            'config_name': repo_name,
-            'location': repo_path,
-            'syncer': 'sync:' + repo_name,
+            "class": "pkgcore.ebuild.repo_objs.RepoConfig",
+            "config_name": repo_name,
+            "location": repo_path,
+            "syncer": "sync:" + repo_name,
         }
         if repo_dict is not None:
             repo_conf.update(repo_dict)
 
         # repo trees
         repo = {
-            'inherit': ('ebuild-repo-common',),
-            'repo_config': 'conf:' + repo_name,
+            "inherit": ("ebuild-repo-common",),
+            "repo_config": "conf:" + repo_name,
         }
 
         # metadata cache
         if repo_obj.cache_format is not None:
-            cache_name = 'cache:' + repo_name
+            cache_name = "cache:" + repo_name
             self[cache_name] = self._make_cache(repo_obj.cache_format, repo_path)
-            repo['cache'] = cache_name
+            repo["cache"] = cache_name
 
-        if repo_name == defaults['main-repo']:
-            repo_conf['default'] = True
-            repo['default'] = True
+        if repo_name == defaults["main-repo"]:
+            repo_conf["default"] = True
+            repo["default"] = True
 
-        self['conf:' + repo_name] = basics.AutoConfigSection(repo_conf)
+        self["conf:" + repo_name] = basics.AutoConfigSection(repo_conf)
         return repo
 
     @_register_repo_type(_supported_repo_types)
     def _repo_sqfs_v1(self, *args, **kwargs):
         """Create ebuild squashfs repo v1 configuration."""
-        repo_name = kwargs['repo_name']
-        repo_opts = kwargs['repo_opts']
+        repo_name = kwargs["repo_name"]
+        repo_opts = kwargs["repo_opts"]
 
-        repo_path = repo_opts['location']
-        sqfs_file = os.path.basename(repo_opts['sync-uri'])
+        repo_path = repo_opts["location"]
+        sqfs_file = os.path.basename(repo_opts["sync-uri"])
         # XXX: Hack for portage-2 profile format support.
-        kwargs['repo_obj'] = repo_objs.SquashfsRepoConfig(sqfs_file, repo_path, repo_name)
+        kwargs["repo_obj"] = repo_objs.SquashfsRepoConfig(
+            sqfs_file, repo_path, repo_name
+        )
 
         repo_dict = {
-            'class': 'pkgcore.ebuild.repo_objs.SquashfsRepoConfig',
-            'sqfs_file': sqfs_file,
+            "class": "pkgcore.ebuild.repo_objs.SquashfsRepoConfig",
+            "sqfs_file": sqfs_file,
         }
-        kwargs['repo_dict'] = repo_dict
+        kwargs["repo_dict"] = repo_dict
         return self._repo_ebuild_v1(*args, **kwargs)
 
     @_register_repo_type(_supported_repo_types)
     def _repo_binpkg_v1(self, repo_name, repo_opts, **kwargs):
         """Create binpkg repo v1 configuration."""
         repo = {
-            'class': 'pkgcore.binpkg.repository.tree',
-            'repo_id': repo_name,
-            'location': repo_opts['location'],
+            "class": "pkgcore.binpkg.repository.tree",
+            "repo_id": repo_name,
+            "location": repo_opts["location"],
         }
         return repo
