@@ -1,10 +1,19 @@
 """gentoo/ebuild specific triggers"""
 
 __all__ = (
-    "collapse_envd", "string_collapse_envd", "env_update",
-    "ConfigProtectInstall", "ConfigProtectUninstall", "preinst_contents_reset",
-    "CollisionProtect", "ProtectOwned", "install_into_symdir_protect",
-    "InfoRegen", "SFPerms", "FixImageSymlinks", "GenerateTriggers",
+    "collapse_envd",
+    "string_collapse_envd",
+    "env_update",
+    "ConfigProtectInstall",
+    "ConfigProtectUninstall",
+    "preinst_contents_reset",
+    "CollisionProtect",
+    "ProtectOwned",
+    "install_into_symdir_protect",
+    "InfoRegen",
+    "SFPerms",
+    "FixImageSymlinks",
+    "GenerateTriggers",
 )
 
 import fnmatch
@@ -21,16 +30,39 @@ from ..merge import const, errors, triggers
 from ..restrictions import values
 from ..system import libtool
 
-colon_parsed = frozenset([
-    "ADA_INCLUDE_PATH", "ADA_OBJECTS_PATH", "INFODIR", "INFOPATH", "LDPATH",
-    "MANPATH", "PATH", "PYTHONPATH", "PKG_CONFIG_PATH", "ROOTPATH"
-])
+colon_parsed = frozenset(
+    [
+        "ADA_INCLUDE_PATH",
+        "ADA_OBJECTS_PATH",
+        "INFODIR",
+        "INFOPATH",
+        "LDPATH",
+        "MANPATH",
+        "PATH",
+        "PYTHONPATH",
+        "PKG_CONFIG_PATH",
+        "ROOTPATH",
+    ]
+)
 
-incrementals = frozenset([
-    'ADA_INCLUDE_PATH', 'ADA_OBJECTS_PATH', 'CLASSPATH', 'CONFIG_PROTECT',
-    'CONFIG_PROTECT_MASK', 'INFODIR', 'INFOPATH', 'KDEDIRS', 'LDPATH',
-    'MANPATH', 'PATH', 'PYTHONPATH', 'ROOTPATH', 'PKG_CONFIG_PATH'
-])
+incrementals = frozenset(
+    [
+        "ADA_INCLUDE_PATH",
+        "ADA_OBJECTS_PATH",
+        "CLASSPATH",
+        "CONFIG_PROTECT",
+        "CONFIG_PROTECT_MASK",
+        "INFODIR",
+        "INFOPATH",
+        "KDEDIRS",
+        "LDPATH",
+        "MANPATH",
+        "PATH",
+        "PYTHONPATH",
+        "ROOTPATH",
+        "PKG_CONFIG_PATH",
+    ]
+)
 
 
 def collapse_envd(base):
@@ -41,8 +73,13 @@ def collapse_envd(base):
         pass
     else:
         for x in env_d_files:
-            if x.endswith(".bak") or x.endswith("~") or x.startswith("._cfg") \
-                    or len(x) <= 2 or not x[0:2].isdigit():
+            if (
+                x.endswith(".bak")
+                or x.endswith("~")
+                or x.startswith("._cfg")
+                or len(x) <= 2
+                or not x[0:2].isdigit()
+            ):
                 continue
             d = read_bash_dict(pjoin(base, x))
             # inefficient, but works.
@@ -76,11 +113,13 @@ def collapse_envd(base):
             collapsed_d[k] = v[-1]
             continue
         if k in loc_colon_parsed:
-            collapsed_d[k] = [_f for _f in iflatten_instance(
-                x.split(':') for x in v) if _f]
+            collapsed_d[k] = [
+                _f for _f in iflatten_instance(x.split(":") for x in v) if _f
+            ]
         else:
-            collapsed_d[k] = [_f for _f in iflatten_instance(
-                x.split() for x in v) if _f]
+            collapsed_d[k] = [
+                _f for _f in iflatten_instance(x.split() for x in v) if _f
+            ]
 
     return collapsed_d, loc_incrementals, loc_colon_parsed
 
@@ -91,19 +130,18 @@ def string_collapse_envd(envd_dict, incrementals, colon_incrementals):
         if k not in incrementals:
             continue
         if k in colon_incrementals:
-            envd_dict[k] = ':'.join(v)
+            envd_dict[k] = ":".join(v)
         else:
-            envd_dict[k] = ' '.join(v)
+            envd_dict[k] = " ".join(v)
 
 
-def update_ldso(ld_search_path, offset='/'):
+def update_ldso(ld_search_path, offset="/"):
     # we do an atomic rename instead of open and write quick
     # enough (avoid the race iow)
-    fp = pjoin(offset, 'etc', 'ld.so.conf')
-    new_f = AtomicWriteFile(
-        fp, uid=os_data.root_uid, gid=os_data.root_uid, perms=0o644)
+    fp = pjoin(offset, "etc", "ld.so.conf")
+    new_f = AtomicWriteFile(fp, uid=os_data.root_uid, gid=os_data.root_uid, perms=0o644)
     new_f.write("# automatically generated, edit env.d files instead\n")
-    new_f.writelines(x.strip()+"\n" for x in ld_search_path)
+    new_f.writelines(x.strip() + "\n" for x in ld_search_path)
     new_f.close()
 
 
@@ -118,13 +156,19 @@ def perform_env_update(root, skip_ldso_update=False):
 
     new_f = AtomicWriteFile(
         pjoin(root, "etc", "profile.env"),
-        uid=os_data.root_uid, gid=os_data.root_gid, perms=0o644)
+        uid=os_data.root_uid,
+        gid=os_data.root_gid,
+        perms=0o644,
+    )
     new_f.write("# autogenerated.  update env.d instead\n")
     new_f.writelines(f'export {k}="{d[k]}"\n' for k in sorted(d))
     new_f.close()
     new_f = AtomicWriteFile(
         pjoin(root, "etc", "profile.csh"),
-        uid=os_data.root_uid, gid=os_data.root_gid, perms=0o644)
+        uid=os_data.root_uid,
+        gid=os_data.root_gid,
+        perms=0o644,
+    )
     new_f.write("# autogenerated, update env.d instead\n")
     new_f.writelines(f'setenv {k}="{d[k]}"\n' for k in sorted(d))
     new_f.close()
@@ -134,7 +178,7 @@ class env_update(triggers.base):
 
     required_csets = ()
     priority = 5
-    _hooks = ('post_unmerge', 'post_merge')
+    _hooks = ("post_unmerge", "post_merge")
 
     def trigger(self, engine):
         perform_env_update(engine.offset)
@@ -160,8 +204,10 @@ def gen_config_protect_filter(offset, extra_protects=(), extra_disables=()):
     collapsed_d.setdefault("CONFIG_PROTECT", []).extend(extra_protects)
     collapsed_d.setdefault("CONFIG_PROTECT_MASK", []).extend(extra_disables)
 
-    r = [values.StrGlobMatch(normpath(x).rstrip("/") + "/")
-         for x in set(stable_unique(collapsed_d["CONFIG_PROTECT"] + ["/etc"]))]
+    r = [
+        values.StrGlobMatch(normpath(x).rstrip("/") + "/")
+        for x in set(stable_unique(collapsed_d["CONFIG_PROTECT"] + ["/etc"]))
+    ]
     if len(r) > 1:
         r = values.OrRestriction(*r)
     else:
@@ -169,13 +215,12 @@ def gen_config_protect_filter(offset, extra_protects=(), extra_disables=()):
     neg = stable_unique(collapsed_d["CONFIG_PROTECT_MASK"])
     if neg:
         if len(neg) == 1:
-            r2 = values.StrGlobMatch(normpath(neg[0]).rstrip("/") + "/",
-                                     negate=True)
+            r2 = values.StrGlobMatch(normpath(neg[0]).rstrip("/") + "/", negate=True)
         else:
             r2 = values.OrRestriction(
                 negate=True,
-                *[values.StrGlobMatch(normpath(x).rstrip("/") + "/")
-                  for x in set(neg)])
+                *[values.StrGlobMatch(normpath(x).rstrip("/") + "/") for x in set(neg)],
+            )
         r = values.AndRestriction(r, r2)
     return r
 
@@ -190,8 +235,7 @@ def gen_collision_ignore_filter(offset, extra_ignores=()):
     for i, x in enumerate(ignored):
         if not x.endswith("/*") and os.path.isdir(x):
             ignored[i] = ignored.rstrip("/") + "/*"
-    ignored = [values.StrRegex(fnmatch.translate(x))
-               for x in stable_unique(ignored)]
+    ignored = [values.StrRegex(fnmatch.translate(x)) for x in stable_unique(ignored)]
     if len(ignored) == 1:
         return ignored[0]
     return values.OrRestriction(*ignored)
@@ -199,9 +243,9 @@ def gen_collision_ignore_filter(offset, extra_ignores=()):
 
 class ConfigProtectInstall(triggers.base):
 
-    required_csets = ('install_existing', 'install')
+    required_csets = ("install_existing", "install")
     priority = 100
-    _hooks = ('pre_merge',)
+    _hooks = ("pre_merge",)
 
     def __init__(self, extra_protects=(), extra_disables=()):
         super().__init__()
@@ -217,7 +261,8 @@ class ConfigProtectInstall(triggers.base):
     def trigger(self, engine, existing_cset, install_cset):
         # hackish, but it works.
         protected_filter = gen_config_protect_filter(
-            engine.offset, self.extra_protects, self.extra_disables).match
+            engine.offset, self.extra_protects, self.extra_disables
+        ).match
         ignore_filter = gen_collision_ignore_filter(engine.offset).match
         protected = {}
 
@@ -226,16 +271,19 @@ class ConfigProtectInstall(triggers.base):
                 replacement = install_cset[x]
                 if not simple_chksum_compare(replacement, x):
                     protected.setdefault(
-                        pjoin(engine.offset,
-                              os.path.dirname(x.location).lstrip(os.path.sep)),
-                        []).append((os.path.basename(replacement.location),
-                                    replacement))
+                        pjoin(
+                            engine.offset,
+                            os.path.dirname(x.location).lstrip(os.path.sep),
+                        ),
+                        [],
+                    ).append((os.path.basename(replacement.location), replacement))
 
         for dir_loc, entries in protected.items():
             updates = {x[0]: [] for x in entries}
             try:
-                existing = sorted(x for x in listdir_files(dir_loc)
-                                  if x.startswith("._cfg"))
+                existing = sorted(
+                    x for x in listdir_files(dir_loc) if x.startswith("._cfg")
+                )
             except FileNotFoundError:
                 # this shouldn't occur.
                 continue
@@ -257,8 +305,9 @@ class ConfigProtectInstall(triggers.base):
                 # check for any updates with the same chksums.
                 count = 0
                 for cfg_count, cfg_fname in updates[fname]:
-                    if simple_chksum_compare(livefs.gen_obj(
-                            pjoin(dir_loc, cfg_fname)), entry):
+                    if simple_chksum_compare(
+                        livefs.gen_obj(pjoin(dir_loc, cfg_fname)), entry
+                    ):
                         count = cfg_count
                         break
                     count = max(count, cfg_count + 1)
@@ -276,9 +325,9 @@ class ConfigProtectInstall(triggers.base):
 
 class ConfigProtectInstall_restore(triggers.base):
 
-    required_csets = ('install',)
+    required_csets = ("install",)
     priority = 10
-    _hooks = ('post_merge',)
+    _hooks = ("post_merge",)
 
     def __init__(self, renames_dict):
         super().__init__()
@@ -296,8 +345,8 @@ class ConfigProtectInstall_restore(triggers.base):
 
 class ConfigProtectUninstall(triggers.base):
 
-    required_csets = ('uninstall_existing', 'uninstall')
-    _hooks = ('pre_unmerge',)
+    required_csets = ("uninstall_existing", "uninstall")
+    _hooks = ("pre_unmerge",)
 
     def trigger(self, engine, existing_cset, uninstall_cset):
         protected_filter = gen_config_protect_filter(engine.offset).match
@@ -322,11 +371,11 @@ class ConfigProtectUninstall(triggers.base):
 class UninstallIgnore(triggers.base):
 
     required_csets = {
-        const.REPLACE_MODE: ('uninstall_existing', 'uninstall', 'old_cset'),
-        const.UNINSTALL_MODE: ('uninstall_existing', 'uninstall'),
+        const.REPLACE_MODE: ("uninstall_existing", "uninstall", "old_cset"),
+        const.UNINSTALL_MODE: ("uninstall_existing", "uninstall"),
     }
 
-    _hooks = ('pre_unmerge',)
+    _hooks = ("pre_unmerge",)
     _engine_types = triggers.UNINSTALLING_MODES
 
     def __init__(self, uninstall_ignore=()):
@@ -334,12 +383,13 @@ class UninstallIgnore(triggers.base):
         self.uninstall_ignore = uninstall_ignore
 
     def trigger(self, engine, existing_cset, uninstall_cset, old_cset={}):
-        ignore = [values.StrRegex(fnmatch.translate(x), match=True)
-                  for x in self.uninstall_ignore]
+        ignore = [
+            values.StrRegex(fnmatch.translate(x), match=True)
+            for x in self.uninstall_ignore
+        ]
         ignore_filter = values.OrRestriction(*ignore).match
 
-        remove = [x for x in existing_cset.iterfiles()
-                  if ignore_filter(x.location)]
+        remove = [x for x in existing_cset.iterfiles() if ignore_filter(x.location)]
         for x in remove:
             # don't remove matching files being uninstalled
             del uninstall_cset[x]
@@ -349,9 +399,9 @@ class UninstallIgnore(triggers.base):
 
 class preinst_contents_reset(triggers.base):
 
-    required_csets = ('new_cset',)
+    required_csets = ("new_cset",)
     priority = 1
-    _hooks = ('pre_merge',)
+    _hooks = ("pre_merge",)
 
     def __init__(self, format_op):
         super().__init__()
@@ -362,7 +412,7 @@ class preinst_contents_reset(triggers.base):
         # modifications to the fs
         cset.clear()
         cs = engine.new._parent.scan_contents(self.format_op.env["D"])
-        if engine.offset != '/':
+        if engine.offset != "/":
             cs = cs.insert_offset(engine.offset)
         cset.update(cs)
 
@@ -371,11 +421,11 @@ class FileCollision(triggers.base):
     """Generic livefs file collision trigger."""
 
     required_csets = {
-        const.INSTALL_MODE: ('install', 'install_existing'),
-        const.REPLACE_MODE: ('install', 'install_existing', 'old_cset')
+        const.INSTALL_MODE: ("install", "install_existing"),
+        const.REPLACE_MODE: ("install", "install_existing", "old_cset"),
     }
 
-    _hooks = ('sanity_check',)
+    _hooks = ("sanity_check",)
     _engine_types = triggers.INSTALLING_MODES
 
     suppress_exceptions = False
@@ -402,9 +452,11 @@ class FileCollision(triggers.base):
 
         # hackish, but it works.
         protected_filter = gen_config_protect_filter(
-            engine.offset, self.extra_protects, self.extra_disables).match
+            engine.offset, self.extra_protects, self.extra_disables
+        ).match
         ignore_filter = gen_collision_ignore_filter(
-            engine.offset, self.extra_ignores).match
+            engine.offset, self.extra_ignores
+        ).match
 
         ignores = []
         for x in colliding:
@@ -426,15 +478,15 @@ class FileCollision(triggers.base):
 
 
 class CollisionProtect(FileCollision):
-
     def collision(self, colliding):
         raise errors.BlockModification(
-            self, "collision-protect: file(s) already exist: ( %s )" %
-            ', '.join(repr(x) for x in sorted(colliding)))
+            self,
+            "collision-protect: file(s) already exist: ( %s )"
+            % ", ".join(repr(x) for x in sorted(colliding)),
+        )
 
 
 class ProtectOwned(FileCollision):
-
     def __init__(self, vdb, *args):
         super().__init__(*args)
         self.vdb = vdb
@@ -451,11 +503,16 @@ class ProtectOwned(FileCollision):
 
         if collisions:
             pkg_collisions = [
-                "( %s ) owned by '%s'" %
-                (', '.join(repr(x) for x in sorted(collisions[pkg_cpvstr])), pkg_cpvstr)
-                for pkg_cpvstr in sorted(collisions.keys())]
+                "( %s ) owned by '%s'"
+                % (
+                    ", ".join(repr(x) for x in sorted(collisions[pkg_cpvstr])),
+                    pkg_cpvstr,
+                )
+                for pkg_cpvstr in sorted(collisions.keys())
+            ]
             raise errors.BlockModification(
-                self, "protect-owned: %s" % (', '.join(pkg_collisions),))
+                self, "protect-owned: %s" % (", ".join(pkg_collisions),)
+            )
 
         # TODO: output a file override warning here
 
@@ -463,11 +520,11 @@ class ProtectOwned(FileCollision):
 class install_into_symdir_protect(triggers.base):
 
     required_csets = {
-        const.INSTALL_MODE: ('install', 'install_existing'),
-        const.REPLACE_MODE: ('install', 'install_existing', 'old_cset')
+        const.INSTALL_MODE: ("install", "install_existing"),
+        const.REPLACE_MODE: ("install", "install_existing", "old_cset"),
     }
 
-    _hooks = ('sanity_check',)
+    _hooks = ("sanity_check",)
     _engine_types = triggers.INSTALLING_MODES
 
     def __init__(self, extra_protects=(), extra_disables=()):
@@ -487,15 +544,16 @@ class install_into_symdir_protect(triggers.base):
             if linkset:
                 for inst_file in install.iterfiles():
                     for sym in linkset:
-                        if inst_file.location.startswith(sym.location + '/'):
+                        if inst_file.location.startswith(sym.location + "/"):
                             install_into_symdir.append(inst_file)
 
         if install_into_symdir:
             raise errors.BlockModification(
                 self,
                 "file(s) installed into symlinked dir, will break when "
-                "removing files from the original dir: ( %s )" %
-                ', '.join(repr(x) for x in sorted(install_into_symdir)))
+                "removing files from the original dir: ( %s )"
+                % ", ".join(repr(x) for x in sorted(install_into_symdir)),
+            )
 
 
 class InfoRegen(triggers.InfoRegen):
@@ -508,15 +566,13 @@ class InfoRegen(triggers.InfoRegen):
             if x not in engine.hooks:
                 continue
             # yucky, but works.
-            wipes = [y for y in engine.hooks[x]
-                     if y.label == triggers.InfoRegen._label]
+            wipes = [y for y in engine.hooks[x] if y.label == triggers.InfoRegen._label]
             for y in wipes:
                 engine.hooks[x].remove(y)
         triggers.InfoRegen.register(self, engine)
 
     def should_skip_directory(self, basepath, files):
-        return any(x.startswith(".keepinfodir")
-                   for x in files)
+        return any(x.startswith(".keepinfodir") for x in files)
 
     def trigger(self, engine, *args):
         self.engine = engine
@@ -535,8 +591,8 @@ class InfoRegen(triggers.InfoRegen):
 
 
 class SFPerms(triggers.base):
-    required_csets = ('new_cset',)
-    _hooks = ('pre_merge',)
+    required_csets = ("new_cset",)
+    _hooks = ("pre_merge",)
     _engine_types = triggers.INSTALLING_MODES
 
     def trigger(self, engine, cset):
@@ -545,22 +601,21 @@ class SFPerms(triggers.base):
             if x.mode & 0o4000:
                 if x.mode & 0o044:
                     engine.observer.warn(
-                        "sfperms: dropping group/world read "
-                        f"due to SetGID: {x!r}")
+                        "sfperms: dropping group/world read " f"due to SetGID: {x!r}"
+                    )
                     resets.append(x.change_attributes(mode=x.mode & ~0o44))
             if x.mode & 0o2000:
                 if x.mode & 0o004:
                     engine.observer.warn(
-                        f"sfperms: dropping world read due to SetUID: {x!r}")
+                        f"sfperms: dropping world read due to SetUID: {x!r}"
+                    )
                     resets.append(x.change_attributes(mode=x.mode & ~0o04))
         cset.update(resets)
 
 
 def register_multilib_strict_trigger(opts):
     locations = opts.get("MULTILIB_STRICT_DIRS")
-    exempt = opts.get(
-        "MULTILIB_STRICT_EXEMPT",
-        "(perl5|gcc|gcc-lib)")
+    exempt = opts.get("MULTILIB_STRICT_EXEMPT", "(perl5|gcc|gcc-lib)")
     deny_pattern = opts.get("MULTILIB_STRICT_DENY")
     if None in (locations, deny_pattern):
         return
@@ -581,8 +636,8 @@ def register_multilib_strict_trigger(opts):
 
 class FixImageSymlinks(triggers.base):
 
-    required_csets = ('new_cset',)
-    _hooks = ('pre_merge',)
+    required_csets = ("new_cset",)
+    _hooks = ("pre_merge",)
 
     def __init__(self, format_op):
         super().__init__()
@@ -598,13 +653,10 @@ class FixImageSymlinks(triggers.base):
         d_len = len(d)
 
         # drop the leading ${D}, and force an abspath via '/'
-        cset.update(
-            x.change_attributes(target=pjoin('/', x.target[d_len:]))
-            for x in l)
+        cset.update(x.change_attributes(target=pjoin("/", x.target[d_len:])) for x in l)
 
 
 class GenerateTriggers:
-
     def __init__(self, domain, settings):
         self.domain = domain
         self.opts = {}
@@ -614,8 +666,11 @@ class GenerateTriggers:
         # ebuild env.
 
         config_lists = (
-            "CONFIG_PROTECT", "CONFIG_PROTECT_MASK", "COLLISION_IGNORE",
-            "INSTALL_MASK", "UNINSTALL_IGNORE",
+            "CONFIG_PROTECT",
+            "CONFIG_PROTECT_MASK",
+            "COLLISION_IGNORE",
+            "INSTALL_MASK",
+            "UNINSTALL_IGNORE",
         )
         for x in config_lists:
             self.opts[x] = settings.pop(x, [])
@@ -624,8 +679,12 @@ class GenerateTriggers:
 
         config_opts = (
             "PKGDIR",
-            "MULTILIB_STRICT_DIRS", "MULTILIB_STRICT_EXEMPT", "MULTILIB_STRICT_DENY",
-            "DEB_REPO_ROOT", "DEB_MAINAINER", "DEB_ARCHITECTURE",
+            "MULTILIB_STRICT_DIRS",
+            "MULTILIB_STRICT_EXEMPT",
+            "MULTILIB_STRICT_DENY",
+            "DEB_REPO_ROOT",
+            "DEB_MAINAINER",
+            "DEB_ARCHITECTURE",
         )
         for x in config_opts:
             self.opts[x] = settings.pop(x, None)
@@ -634,18 +693,27 @@ class GenerateTriggers:
         yield env_update()
 
         yield ConfigProtectInstall(
-            self.opts["CONFIG_PROTECT"], self.opts["CONFIG_PROTECT_MASK"])
+            self.opts["CONFIG_PROTECT"], self.opts["CONFIG_PROTECT_MASK"]
+        )
         yield ConfigProtectUninstall()
 
         if "collision-protect" in self.domain.features:
             yield CollisionProtect(
-                self.opts["CONFIG_PROTECT"], self.opts["CONFIG_PROTECT_MASK"],
-                self.opts["COLLISION_IGNORE"])
+                self.opts["CONFIG_PROTECT"],
+                self.opts["CONFIG_PROTECT_MASK"],
+                self.opts["COLLISION_IGNORE"],
+            )
 
-        if "protect-owned" in self.domain.features and "collision-protect" not in self.domain.features:
+        if (
+            "protect-owned" in self.domain.features
+            and "collision-protect" not in self.domain.features
+        ):
             yield ProtectOwned(
-                self.domain.installed_repos, self.opts["CONFIG_PROTECT"],
-                self.opts["CONFIG_PROTECT_MASK"], self.opts["COLLISION_IGNORE"])
+                self.domain.installed_repos,
+                self.opts["CONFIG_PROTECT"],
+                self.opts["CONFIG_PROTECT_MASK"],
+                self.opts["COLLISION_IGNORE"],
+            )
 
         if "multilib-strict" in self.domain.features:
             yield register_multilib_strict_trigger(self.opts)
@@ -654,7 +722,8 @@ class GenerateTriggers:
             yield SFPerms()
 
         yield install_into_symdir_protect(
-            self.opts["CONFIG_PROTECT"], self.opts["CONFIG_PROTECT_MASK"])
+            self.opts["CONFIG_PROTECT"], self.opts["CONFIG_PROTECT_MASK"]
+        )
 
         # TODO: support multiple binpkg repo targets?
         pkgdir = self.opts.get("PKGDIR", None)
@@ -667,22 +736,27 @@ class GenerateTriggers:
             except IndexError:
                 target_repo = None
         if target_repo is not None:
-            if 'buildpkg' in self.domain.features:
-                yield triggers.SavePkg(pristine='no', target_repo=target_repo)
-            elif 'pristine-buildpkg' in self.domain.features:
-                yield triggers.SavePkg(pristine='yes', target_repo=target_repo)
-            elif 'buildsyspkg' in self.domain.features:
+            if "buildpkg" in self.domain.features:
+                yield triggers.SavePkg(pristine="no", target_repo=target_repo)
+            elif "pristine-buildpkg" in self.domain.features:
+                yield triggers.SavePkg(pristine="yes", target_repo=target_repo)
+            elif "buildsyspkg" in self.domain.features:
                 yield triggers.SavePkgIfInPkgset(
-                    pristine='yes', target_repo=target_repo, pkgset=self.domain.profile.system)
-            elif 'unmerge-backup' in self.domain.features:
+                    pristine="yes",
+                    target_repo=target_repo,
+                    pkgset=self.domain.profile.system,
+                )
+            elif "unmerge-backup" in self.domain.features:
                 yield triggers.SavePkgUnmerging(target_repo=target_repo)
 
-        if 'splitdebug' in self.domain.features:
-            yield triggers.BinaryDebug(mode='split', compress=('compressdebug' in self.domain.features))
-        elif 'strip' in self.domain.features or 'nostrip' not in self.domain.features:
-            yield triggers.BinaryDebug(mode='strip')
+        if "splitdebug" in self.domain.features:
+            yield triggers.BinaryDebug(
+                mode="split", compress=("compressdebug" in self.domain.features)
+            )
+        elif "strip" in self.domain.features or "nostrip" not in self.domain.features:
+            yield triggers.BinaryDebug(mode="strip")
 
-        if '-fixlafiles' not in self.domain.features:
+        if "-fixlafiles" not in self.domain.features:
             yield libtool.FixLibtoolArchivesTrigger()
 
         for x in ("man", "info", "doc"):
