@@ -27,9 +27,9 @@ from snakeoil.osutils import normpath
 
 from ..fs import contents, livefs
 from ..operations import observer as observer_mod
-from ..plugin import get_plugins
 from . import errors
 from .const import INSTALL_MODE, REPLACE_MODE, UNINSTALL_MODE
+from .triggers import default_plugins_triggers
 
 
 def alias_cset(alias, engine, csets):
@@ -37,7 +37,7 @@ def alias_cset(alias, engine, csets):
     return csets[alias]
 
 
-def map_new_cset_livefs(engine, csets, cset_name='new_cset'):
+def map_new_cset_livefs(engine, csets, cset_name="new_cset"):
     """Find symlinks on disk that redirect new_cset, and return a livefs localized cset."""
     initial = csets[cset_name]
     ondisk = contents.contentsSet(livefs.intersect(initial.iterdirs(), realpath=False))
@@ -48,19 +48,23 @@ def map_new_cset_livefs(engine, csets, cset_name='new_cset'):
 
 class MergeEngine:
 
-    install_hooks = {x: [] for x in
-        ("sanity_check", "pre_merge", "merge", "post_merge", "final")}
-    uninstall_hooks = {x: [] for x in
-        ("sanity_check", "pre_unmerge", "unmerge", "post_unmerge", "final")}
-    replace_hooks = {x: [] for x in
-        set(chain(install_hooks.keys(), uninstall_hooks.keys()))}
+    install_hooks = {
+        x: [] for x in ("sanity_check", "pre_merge", "merge", "post_merge", "final")
+    }
+    uninstall_hooks = {
+        x: []
+        for x in ("sanity_check", "pre_unmerge", "unmerge", "post_unmerge", "final")
+    }
+    replace_hooks = {
+        x: [] for x in set(chain(install_hooks.keys(), uninstall_hooks.keys()))
+    }
 
     install_csets = {
         "install_existing": "get_install_livefs_intersect",
         "resolved_install": map_new_cset_livefs,
-        'new_cset': partial(alias_cset, 'raw_new_cset'),
-        "install": partial(alias_cset, 'new_cset'),
-        "replace": partial(alias_cset, 'new_cset'),
+        "new_cset": partial(alias_cset, "raw_new_cset"),
+        "install": partial(alias_cset, "new_cset"),
+        "replace": partial(alias_cset, "new_cset"),
     }
     uninstall_csets = {
         "uninstall_existing": partial(alias_cset, "uninstall"),
@@ -69,8 +73,9 @@ class MergeEngine:
     }
     replace_csets = install_csets.copy()
     replace_csets.update(uninstall_csets)
-    replace_csets["modifying"] = (
-        lambda e, c: c["resolved_install"].intersection(c["uninstall"]))
+    replace_csets["modifying"] = lambda e, c: c["resolved_install"].intersection(
+        c["uninstall"]
+    )
     replace_csets["uninstall"] = "get_remove_cset"
     replace_csets["replace"] = "get_replace_cset"
     replace_csets["install_existing"] = "get_install_livefs_intersect"
@@ -81,14 +86,24 @@ class MergeEngine:
 
     allow_reuse = True
 
-    def __init__(self, mode, tempdir, hooks, csets, preserves, observer,
-                 offset=None, disable_plugins=False, parallelism=None):
+    def __init__(
+        self,
+        mode,
+        tempdir,
+        hooks,
+        csets,
+        preserves,
+        observer,
+        offset=None,
+        disable_plugins=False,
+        parallelism=None,
+    ):
         if observer is None:
             observer = observer_mod.repo_observer(observer_mod.null_output)
         self.observer = observer
         self.mode = mode
         if tempdir is not None:
-            tempdir = normpath(tempdir) + '/'
+            tempdir = normpath(tempdir) + "/"
         self.tempdir = tempdir
 
         self.parallelism = parallelism if parallelism is not None else cpu_count()
@@ -97,15 +112,15 @@ class MergeEngine:
         self.preserve_csets = []
         self.cset_sources = {}
         # instantiate these separately so their values are preserved
-        self.preserved_csets = LazyValDict(
-            self.preserve_csets, self._get_cset_source)
+        self.preserved_csets = LazyValDict(self.preserve_csets, self._get_cset_source)
         for k, v in csets.items():
             if isinstance(v, str):
                 v = getattr(self, v, v)
             if not callable(v):
                 raise TypeError(
                     "cset values must be either the string name of "
-                    f"existing methods, or callables (got {v})")
+                    f"existing methods, or callables (got {v})"
+                )
 
             if k in preserves:
                 self.add_preserved_cset(k, v)
@@ -118,9 +133,8 @@ class MergeEngine:
 
         if not disable_plugins:
             # merge in default triggers first.
-            for trigger in get_plugins('triggers'):
-                t = trigger()
-                t.register(self)
+            for trigger in default_plugins_triggers():
+                trigger().register(self)
 
         # merge in overrides
         for hook, triggers in hooks.items():
@@ -132,8 +146,7 @@ class MergeEngine:
             setattr(self, x, partial(self.execute_hook, x))
 
     @classmethod
-    def install(cls, tempdir, pkg, offset=None, observer=None,
-                disable_plugins=False):
+    def install(cls, tempdir, pkg, offset=None, observer=None, disable_plugins=False):
         """Generate a MergeEngine instance configured for installing a pkg.
 
         :param tempdir: tempspace for the merger to use; this space it must
@@ -148,20 +161,28 @@ class MergeEngine:
         csets = cls.install_csets.copy()
         if "raw_new_cset" not in csets:
             csets["raw_new_cset"] = post_curry(cls.get_pkg_contents, pkg)
-        o = cls(INSTALL_MODE, tempdir, hooks, csets, cls.install_csets_preserve,
-                observer, offset=offset, disable_plugins=disable_plugins)
+        o = cls(
+            INSTALL_MODE,
+            tempdir,
+            hooks,
+            csets,
+            cls.install_csets_preserve,
+            observer,
+            offset=offset,
+            disable_plugins=disable_plugins,
+        )
 
-        if o.offset != '/':
+        if o.offset != "/":
             # wrap the results of new_cset to pass through an offset generator
             o.cset_sources["raw_new_cset"] = post_curry(
-                o.generate_offset_cset, o.cset_sources["raw_new_cset"])
+                o.generate_offset_cset, o.cset_sources["raw_new_cset"]
+            )
 
         o.new = pkg
         return o
 
     @classmethod
-    def uninstall(cls, tempdir, pkg, offset=None, observer=None,
-                  disable_plugins=False):
+    def uninstall(cls, tempdir, pkg, offset=None, observer=None, disable_plugins=False):
         """Generate a MergeEngine instance configured for uninstalling a pkg.
 
         :param tempdir: tempspace for the merger to use; this space it must
@@ -177,20 +198,30 @@ class MergeEngine:
 
         if "raw_old_cset" not in csets:
             csets["raw_old_cset"] = post_curry(cls.get_pkg_contents, pkg)
-        o = cls(UNINSTALL_MODE, tempdir, hooks, csets, cls.uninstall_csets_preserve,
-                observer, offset=offset, disable_plugins=disable_plugins)
+        o = cls(
+            UNINSTALL_MODE,
+            tempdir,
+            hooks,
+            csets,
+            cls.uninstall_csets_preserve,
+            observer,
+            offset=offset,
+            disable_plugins=disable_plugins,
+        )
 
-        if o.offset != '/':
+        if o.offset != "/":
             # wrap the results of new_cset to pass through an offset generator
             o.cset_sources["old_cset"] = post_curry(
-                o.generate_offset_cset, o.cset_sources["old_cset"])
+                o.generate_offset_cset, o.cset_sources["old_cset"]
+            )
 
         o.old = pkg
         return o
 
     @classmethod
-    def replace(cls, tempdir, old, new, offset=None, observer=None,
-                disable_plugins=False):
+    def replace(
+        cls, tempdir, old, new, offset=None, observer=None, disable_plugins=False
+    ):
         """Generate a MergeEngine instance configured for replacing a pkg.
 
         :param tempdir: tempspace for the merger to use; this space it must
@@ -206,18 +237,27 @@ class MergeEngine:
 
         csets = cls.replace_csets.copy()
 
-        csets.setdefault('raw_old_cset', post_curry(cls.get_pkg_contents, old))
-        csets.setdefault('raw_new_cset', post_curry(cls.get_pkg_contents, new))
+        csets.setdefault("raw_old_cset", post_curry(cls.get_pkg_contents, old))
+        csets.setdefault("raw_new_cset", post_curry(cls.get_pkg_contents, new))
 
-        o = cls(REPLACE_MODE, tempdir, hooks, csets, cls.replace_csets_preserve,
-                observer, offset=offset, disable_plugins=disable_plugins)
+        o = cls(
+            REPLACE_MODE,
+            tempdir,
+            hooks,
+            csets,
+            cls.replace_csets_preserve,
+            observer,
+            offset=offset,
+            disable_plugins=disable_plugins,
+        )
 
-        if o.offset != '/':
+        if o.offset != "/":
             for k in ("raw_old_cset", "raw_new_cset"):
                 # wrap the results of new_cset to pass through an
                 # offset generator
                 o.cset_sources[k] = post_curry(
-                    o.generate_offset_cset, o.cset_sources[k])
+                    o.generate_offset_cset, o.cset_sources[k]
+                )
 
         o.old = old
         o.new = new
@@ -242,8 +282,9 @@ class MergeEngine:
 
         Used in transitioning between hook points
         """
-        self.csets = StackedDict(self.preserved_csets,
-            LazyValDict(self.cset_sources, self._get_cset_source))
+        self.csets = StackedDict(
+            self.preserved_csets, LazyValDict(self.cset_sources, self._get_cset_source)
+        )
 
     def _get_cset_source(self, key):
         return self.cset_sources[key](self, self.csets)
@@ -280,8 +321,7 @@ class MergeEngine:
         :param trigger: :class:`pkgcore.merge.triggers.base` to add
         """
         if hook_name not in self.hooks:
-            raise KeyError(
-                f"trigger {trigger!r}'s hook {hook_name} isn't a known hook")
+            raise KeyError(f"trigger {trigger!r}'s hook {hook_name} isn't a known hook")
 
         if required_csets is not None:
             for rcs in required_csets:
@@ -296,7 +336,9 @@ class MergeEngine:
         try:
             self.phase = hook
             self.regenerate_csets()
-            for trigger in sorted(self.hooks[hook], key=operator.attrgetter("priority")):
+            for trigger in sorted(
+                self.hooks[hook], key=operator.attrgetter("priority")
+            ):
                 # error checking needed here.
                 self.observer.trigger_start(hook, trigger)
                 try:
@@ -306,11 +348,13 @@ class MergeEngine:
                         raise
                     except errors.BlockModification as e:
                         self.observer.error(
-                            f"modification was blocked by trigger {trigger!r}: {e}")
+                            f"modification was blocked by trigger {trigger!r}: {e}"
+                        )
                         raise
                     except errors.ModificationError as e:
                         self.observer.error(
-                            f"modification error occurred during trigger {trigger!r}: {e}")
+                            f"modification error occurred during trigger {trigger!r}: {e}"
+                        )
                         raise
                     except Exception as e:
                         if not trigger.suppress_exceptions:
@@ -351,7 +395,9 @@ class MergeEngine:
     @staticmethod
     def _get_livefs_intersect_cset(engine, csets, cset_name, realpath=False):
         """Generate the livefs intersection against a cset."""
-        return contents.contentsSet(livefs.intersect(csets[cset_name], realpath=realpath))
+        return contents.contentsSet(
+            livefs.intersect(csets[cset_name], realpath=realpath)
+        )
 
     @staticmethod
     def get_install_livefs_intersect(engine, csets):
@@ -365,8 +411,8 @@ class MergeEngine:
 
     def get_merged_cset(self, strip_offset=True):
         cset = self.csets["install"]
-        if self.offset not in (None, '/') and strip_offset:
-            rewrite = contents.change_offset_rewriter(self.offset, '/', cset)
+        if self.offset not in (None, "/") and strip_offset:
+            rewrite = contents.change_offset_rewriter(self.offset, "/", cset)
             cset = contents.contentsSet(rewrite)
         return cset
 
@@ -396,7 +442,7 @@ class MergeEngine:
 
         # clone it into tempspace; it's required we control the tempspace,
         # so this function is safe in our usage.
-        fd, path = tempfile.mkstemp(prefix='merge-engine-', dir=self.tempdir)
+        fd, path = tempfile.mkstemp(prefix="merge-engine-", dir=self.tempdir)
 
         # XXX: annoying quirk of python, we don't want append mode, so 'a+'
         # isn't viable; wr will truncate the file, so data_source uses r+.
@@ -405,7 +451,8 @@ class MergeEngine:
         # just touch the filepath.
         touch(path)
         new_source = data_source.local_source(
-            path, True, encoding=getattr(fsobj, 'encoding', None))
+            path, True, encoding=getattr(fsobj, "encoding", None)
+        )
 
         if source and not empty:
             data_source.transfer(source.bytes_fsobj(), new_source.bytes_fsobj(True))
