@@ -14,7 +14,8 @@ class _Base:
 
     def __iter__(self):
         restrict = packages.PackageRestriction(
-            "package_is_real", values.EqualityMatch(True))
+            "package_is_real", values.EqualityMatch(True)
+        )
         for repo in self.vdbs:
             for pkg in repo.itermatch(restrict):
                 yield self.getter(pkg)
@@ -22,11 +23,13 @@ class _Base:
 
 class Installed(_Base):
     """Set of packages holding slotted atoms of all installed packages."""
-    pkgcore_config_type = ConfigHint({'vdb': 'refs:repo'}, typename='pkgset')
-    getter = operator.attrgetter('slotted_atom')
+
+    pkgcore_config_type = ConfigHint({"vdb": "refs:repo"}, typename="pkgset")
+    getter = operator.attrgetter("slotted_atom")
 
 
 class VersionedInstalled(_Base):
     """Set of packages holding versioned atoms of all installed packages."""
-    pkgcore_config_type = ConfigHint({'vdb': 'refs:repo'}, typename='pkgset')
-    getter = operator.attrgetter('versioned_atom')
+
+    pkgcore_config_type = ConfigHint({"vdb": "refs:repo"}, typename="pkgset")
+    getter = operator.attrgetter("versioned_atom")
