@@ -11,11 +11,8 @@ from .installed import VersionedInstalled
 class EclassConsumerSet(VersionedInstalled):
 
     pkgcore_config_type = ConfigHint(
-        typename='pkgset',
-        types={
-            'vdb': 'refs:repo',
-            'repos': 'refs:repo',
-            'eclasses': 'list'},
+        typename="pkgset",
+        types={"vdb": "refs:repo", "repos": "refs:repo", "eclasses": "list"},
     )
 
     def __init__(self, vdb, repos, eclasses):
@@ -29,7 +26,7 @@ class EclassConsumerSet(VersionedInstalled):
             if not pkgs:
                 # pkg is installed but no longer in any repo, just ignore it.
                 continue
-            assert len(pkgs) == 1, 'I do not know what I am doing: %r' % (pkgs,)
+            assert len(pkgs) == 1, "I do not know what I am doing: %r" % (pkgs,)
             pkg = pkgs[0]
-            if self.eclasses.isdisjoint(pkg.data.get('_eclasses_', ())):
+            if self.eclasses.isdisjoint(pkg.data.get("_eclasses_", ())):
                 yield atom
