@@ -29,25 +29,58 @@ from ..util import commandline
 
 pkgcore_opts = commandline.ArgumentParser(domain=False, script=(__file__, __name__))
 argparser = commandline.ArgumentParser(
-    suppress=True, description=__doc__, parents=(pkgcore_opts,))
+    suppress=True, description=__doc__, parents=(pkgcore_opts,)
+)
 subparsers = argparser.add_subparsers(description="general system maintenance")
 
-shared_options = (commandline.ArgumentParser(
-    config=False, color=False, debug=False, quiet=False, verbose=False,
-    version=False, domain=False, add_help=False),)
-shared_options_domain = (commandline.ArgumentParser(
-    config=False, color=False, debug=False, quiet=False, verbose=False,
-    version=False, domain=True, add_help=False),)
+shared_options = (
+    commandline.ArgumentParser(
+        config=False,
+        color=False,
+        debug=False,
+        quiet=False,
+        verbose=False,
+        version=False,
+        domain=False,
+        add_help=False,
+    ),
+)
+shared_options_domain = (
+    commandline.ArgumentParser(
+        config=False,
+        color=False,
+        debug=False,
+        quiet=False,
+        verbose=False,
+        version=False,
+        domain=True,
+        add_help=False,
+    ),
+)
 
 sync = subparsers.add_parser(
-    "sync", parents=shared_options,
-    description="synchronize a local repository with its defined remote")
+    "sync",
+    parents=shared_options,
+    description="synchronize a local repository with its defined remote",
+)
 sync.add_argument(
-    'repos', metavar='repo', nargs='*', help="repo(s) to sync",
-    action=commandline.StoreRepoObject, store_name=True, repo_type='config')
+    "repos",
+    metavar="repo",
+    nargs="*",
+    help="repo(s) to sync",
+    action=commandline.StoreRepoObject,
+    store_name=True,
+    repo_type="config",
+)
 sync.add_argument(
-    '-f', '--force', action='store_true', default=False,
-    help="force syncing to occur regardless of staleness checks")
+    "-f",
+    "--force",
+    action="store_true",
+    default=False,
+    help="force syncing to occur regardless of staleness checks",
+)
+
+
 @sync.bind_main_func
 def sync_main(options, out, err):
     """Update local repos to match their remotes."""
@@ -62,19 +95,18 @@ def sync_main(options, out, err):
             continue
         out.write(f"*** syncing {repo_name}")
         ret = False
-        err_msg = ''
+        err_msg = ""
         # repo operations don't yet take an observer, thus flush
         # output to keep lines consistent.
         out.flush()
         err.flush()
         try:
-            ret = repo.operations.sync(
-                force=options.force, verbosity=options.verbosity)
+            ret = repo.operations.sync(force=options.force, verbosity=options.verbosity)
         except OperationError as e:
-            exc = getattr(e, '__cause__', e)
+            exc = getattr(e, "__cause__", e)
             if not isinstance(exc, PkgcoreUserException):
                 raise
-            err_msg = f': {exc}'
+            err_msg = f": {exc}"
         if not ret:
             out.write(f"!!! failed syncing {repo_name}{err_msg}")
             failed.append(repo_name)
@@ -87,8 +119,8 @@ def sync_main(options, out, err):
     total = len(succeeded) + len(failed)
     if total > 1:
         results = []
-        succeeded = ', '.join(sorted(succeeded))
-        failed = ', '.join(sorted(failed))
+        succeeded = ", ".join(sorted(succeeded))
+        failed = ", ".join(sorted(failed))
         if succeeded:
             results.append(f"*** synced: {succeeded}")
         if failed:
@@ -100,25 +132,43 @@ def sync_main(options, out, err):
 
 # TODO: restrict to required repo types
 copy = subparsers.add_parser(
-    "copy", parents=shared_options_domain,
+    "copy",
+    parents=shared_options_domain,
     description="copy binpkgs between repos; primarily useful for "
-    "quickpkging a livefs pkg")
+    "quickpkging a livefs pkg",
+)
 copy.add_argument(
-    'target_repo', action=commandline.StoreRepoObject, repo_type='binary-raw',
-    writable=True, help="repository to add packages to")
+    "target_repo",
+    action=commandline.StoreRepoObject,
+    repo_type="binary-raw",
+    writable=True,
+    help="repository to add packages to",
+)
 commandline.make_query(
-    copy, nargs='+', dest='query',
-    help="packages matching any of these restrictions will be selected "
-    "for copying")
+    copy,
+    nargs="+",
+    dest="query",
+    help="packages matching any of these restrictions will be selected " "for copying",
+)
 copy_opts = copy.add_argument_group("subcommand options")
 copy_opts.add_argument(
-    '-s', '--source-repo', default=None, repo_type='installed',
+    "-s",
+    "--source-repo",
+    default=None,
+    repo_type="installed",
     action=commandline.StoreRepoObject,
     help="copy strictly from the supplied repository; else it copies from "
-    "wherever a match is found")
+    "wherever a match is found",
+)
 copy_opts.add_argument(
-    '-i', '--ignore-existing', default=False, action='store_true',
-    help="if a matching pkg already exists in the target, don't update it")
+    "-i",
+    "--ignore-existing",
+    default=False,
+    action="store_true",
+    help="if a matching pkg already exists in the target, don't update it",
+)
+
+
 @copy.bind_main_func
 def copy_main(options, out, err):
     """Copy pkgs between repos."""
@@ -134,12 +184,12 @@ def copy_main(options, out, err):
             out.write(f"skipping existing pkg: {pkg.cpvstr}")
             continue
         # TODO: remove this once we limit src repos to non-virtual (pkg.provided) repos
-        if not getattr(pkg, 'package_is_real', True):
+        if not getattr(pkg, "package_is_real", True):
             out.write(f"skipping virtual pkg: {pkg.cpvstr}")
             continue
 
         out.write(f"copying {pkg}... ")
-        if getattr(getattr(pkg, 'repo', None), 'livefs', False):
+        if getattr(getattr(pkg, "repo", None), "livefs", False):
             out.write("forcing regen of contents due to src being livefs..")
             new_contents = contents.contentsSet(mutable=True)
             for fsobj in pkg.contents:
@@ -147,17 +197,19 @@ def copy_main(options, out, err):
                     new_contents.add(livefs.gen_obj(fsobj.location))
                 except FileNotFoundError:
                     err.write(
-                        f"warning: dropping fs obj {fsobj!r} since it doesn't exist")
+                        f"warning: dropping fs obj {fsobj!r} since it doesn't exist"
+                    )
                 except OSError as oe:
                     err.write(
                         f"failed accessing fs obj {fsobj!r}; {oe}\n"
-                        "aborting this copy")
+                        "aborting this copy"
+                    )
                     failures = True
                     new_contents = None
                     break
             if new_contents is None:
                 continue
-            pkg = mutated.MutatedPkg(pkg, {'contents': new_contents})
+            pkg = mutated.MutatedPkg(pkg, {"contents": new_contents})
 
         target_repo.operations.install_or_replace(pkg).finish()
         out.write("completed\n")
@@ -183,26 +235,31 @@ def update_use_local_desc(repo, observer):
     f = None
 
     def _raise_xml_error(exc):
-        observer.error(f'{cat}/{pkg}: failed parsing metadata.xml: {str(exc)}')
+        observer.error(f"{cat}/{pkg}: failed parsing metadata.xml: {str(exc)}")
         nonlocal ret
         ret = 1
 
     try:
         f = AtomicWriteFile(use_local_desc)
-        f.write(textwrap.dedent('''\
+        f.write(
+            textwrap.dedent(
+                """\
             # This file is deprecated as per GLEP 56 in favor of metadata.xml.
             # Please add your descriptions to your package's metadata.xml ONLY.
-            # * generated automatically using pmaint *\n\n'''))
-        with patch('pkgcore.log.logger.error', _raise_xml_error):
+            # * generated automatically using pmaint *\n\n"""
+            )
+        )
+        with patch("pkgcore.log.logger.error", _raise_xml_error):
             for cat, pkgs in sorted(repo.packages.items()):
                 for pkg in sorted(pkgs):
                     metadata = repo._get_metadata_xml(cat, pkg)
                     for flag, desc in sorted(metadata.local_use.items()):
-                        f.write(f'{cat}/{pkg}:{flag} - {desc}\n')
+                        f.write(f"{cat}/{pkg}:{flag} - {desc}\n")
         f.close()
     except IOError as e:
         observer.error(
-            f"Unable to update use.local.desc file {use_local_desc!r}: {e.strerror}")
+            f"Unable to update use.local.desc file {use_local_desc!r}: {e.strerror}"
+        )
         ret = os.EX_IOERR
     finally:
         if f is not None:
@@ -225,7 +282,7 @@ def update_pkg_desc_index(repo, observer):
                 for cpv in reversed(cpvs):
                     try:
                         desc = repo[(cat, pkg, cpv.fullver)].description
-                        versions = ' '.join(x.fullver for x in cpvs)
+                        versions = " ".join(x.fullver for x in cpvs)
                         f.write(f"{cat}/{pkg} {versions}: {desc}\n")
                         break
                     except MetadataException as e:
@@ -234,7 +291,8 @@ def update_pkg_desc_index(repo, observer):
         f.close()
     except IOError as e:
         observer.error(
-            f"Unable to update pkg_desc_index file {pkg_desc_index!r}: {e.strerror}")
+            f"Unable to update pkg_desc_index file {pkg_desc_index!r}: {e.strerror}"
+        )
         ret = os.EX_IOERR
     finally:
         if f is not None:
@@ -244,45 +302,73 @@ def update_pkg_desc_index(repo, observer):
 
 
 regen = subparsers.add_parser(
-    "regen", parents=shared_options_domain,
-    description="regenerate repository caches")
+    "regen", parents=shared_options_domain, description="regenerate repository caches"
+)
 regen.add_argument(
-    'repos', metavar='repo', nargs='*',
-    action=commandline.StoreRepoObject, repo_type='source-raw', allow_external_repos=True,
-    help="repo(s) to regenerate caches for")
+    "repos",
+    metavar="repo",
+    nargs="*",
+    action=commandline.StoreRepoObject,
+    repo_type="source-raw",
+    allow_external_repos=True,
+    help="repo(s) to regenerate caches for",
+)
 regen_opts = regen.add_argument_group("subcommand options")
 regen_opts.add_argument(
-    "--disable-eclass-caching", action='store_true', default=False,
+    "--disable-eclass-caching",
+    action="store_true",
+    default=False,
     help="""
         For regen operation, pkgcore internally turns on an optimization that
         caches eclasses into individual functions thus parsing the eclass only
         twice max per EBD processor. Disabling this optimization via this
         option results in ~2x slower regeneration. Disable it only if you
         suspect the optimization is somehow causing issues.
-    """)
+    """,
+)
 regen_opts.add_argument(
-    "-t", "--threads", type=int,
+    "-t",
+    "--threads",
+    type=int,
     default=arghparse.DelayedValue(_get_default_jobs, 100),
     help="number of threads to use",
     docs="""
         Number of threads to use for regeneration, defaults to using all
         available processors.
-    """)
+    """,
+)
 regen_opts.add_argument(
-    "--force", action='store_true', default=False,
-    help="force regeneration to occur regardless of staleness checks or repo settings")
+    "--force",
+    action="store_true",
+    default=False,
+    help="force regeneration to occur regardless of staleness checks or repo settings",
+)
 regen_opts.add_argument(
-    "--dir", dest='cache_dir', type=arghparse.create_dir,
-    help="use separate directory to store repository caches")
+    "--dir",
+    dest="cache_dir",
+    type=arghparse.create_dir,
+    help="use separate directory to store repository caches",
+)
 regen_opts.add_argument(
-    "--rsync", action='store_true', default=False,
-    help="perform actions necessary for rsync repos (update metadata/timestamp.chk)")
+    "--rsync",
+    action="store_true",
+    default=False,
+    help="perform actions necessary for rsync repos (update metadata/timestamp.chk)",
+)
 regen_opts.add_argument(
-    "--use-local-desc", action='store_true', default=False,
-    help="update local USE flag description cache (profiles/use.local.desc)")
+    "--use-local-desc",
+    action="store_true",
+    default=False,
+    help="update local USE flag description cache (profiles/use.local.desc)",
+)
 regen_opts.add_argument(
-    "--pkg-desc-index", action='store_true', default=False,
-    help="update package description cache (metadata/pkg_desc_index)")
+    "--pkg-desc-index",
+    action="store_true",
+    default=False,
+    help="update package description cache (metadata/pkg_desc_index)",
+)
+
+
 @regen.bind_main_func
 def regen_main(options, out, err):
     """Regenerate a repository cache."""
@@ -293,25 +379,29 @@ def regen_main(options, out, err):
         if options.cache_dir is not None:
             # recreate new repo object with cache dir override
             cache = (md5_cache(pjoin(options.cache_dir.rstrip(os.sep), repo.repo_id)),)
-            repo = ebuild_repo.tree(
-                options.config, repo.config, cache=cache)
+            repo = ebuild_repo.tree(options.config, repo.config, cache=cache)
         if not repo.operations.supports("regen_cache"):
             out.write(f"repo {repo} doesn't support cache regeneration")
             continue
-        elif not getattr(repo, 'cache', False) and not options.force:
+        elif not getattr(repo, "cache", False) and not options.force:
             out.write(f"skipping repo {repo}: cache disabled")
             continue
 
         start_time = time.time()
-        ret.append(repo.operations.regen_cache(
-            threads=options.threads, observer=observer, force=options.force,
-            eclass_caching=(not options.disable_eclass_caching)))
+        ret.append(
+            repo.operations.regen_cache(
+                threads=options.threads,
+                observer=observer,
+                force=options.force,
+                eclass_caching=(not options.disable_eclass_caching),
+            )
+        )
         end_time = time.time()
 
         if options.verbosity > 0:
             out.write(
-                "finished %d nodes in %.2f seconds" %
-                (len(repo), end_time - start_time))
+                "finished %d nodes in %.2f seconds" % (len(repo), end_time - start_time)
+            )
 
         if options.rsync:
             timestamp = pjoin(repo.location, "metadata", "timestamp.chk")
@@ -319,7 +409,9 @@ def regen_main(options, out, err):
                 with open(timestamp, "w") as f:
                     f.write(time.strftime("%a, %d %b %Y %H:%M:%S +0000", time.gmtime()))
             except IOError as e:
-                err.write(f"Unable to update timestamp file {timestamp!r}: {e.strerror}")
+                err.write(
+                    f"Unable to update timestamp file {timestamp!r}: {e.strerror}"
+                )
                 ret.append(os.EX_IOERR)
 
         if options.use_local_desc:
@@ -331,17 +423,24 @@ def regen_main(options, out, err):
 
 
 env_update = subparsers.add_parser(
-    "env-update", description="update env.d and ldconfig",
-    parents=shared_options_domain)
+    "env-update", description="update env.d and ldconfig", parents=shared_options_domain
+)
 env_update_opts = env_update.add_argument_group("subcommand options")
 env_update_opts.add_argument(
-    "--skip-ldconfig", action='store_true', default=False,
-    help="do not update etc/ldso.conf and ld.so.cache")
+    "--skip-ldconfig",
+    action="store_true",
+    default=False,
+    help="do not update etc/ldso.conf and ld.so.cache",
+)
+
+
 @env_update.bind_main_func
 def env_update_main(options, out, err):
-    root = getattr(options.domain, 'root', None)
+    root = getattr(options.domain, "root", None)
     if root is None:
-        env_update.error("domain specified lacks a root setting; is it a virtual or remote domain?")
+        env_update.error(
+            "domain specified lacks a root setting; is it a virtual or remote domain?"
+        )
 
     out.write(f"updating env for {root!r}...")
     try:
@@ -364,52 +463,67 @@ class EclassArgs(argparse.Action):
                 path = os.path.realpath(val)
                 if os.path.isdir(path):
                     eclasses.extend(os.listdir(path))
-                elif val.endswith('.eclass'):
+                elif val.endswith(".eclass"):
                     eclasses.append(path)
                 else:
-                    raise argparse.ArgumentError(self, f'invalid eclass: {val!r}')
-            eclasses = sorted(x for x in eclasses if x.endswith('.eclass'))
+                    raise argparse.ArgumentError(self, f"invalid eclass: {val!r}")
+            eclasses = sorted(x for x in eclasses if x.endswith(".eclass"))
         else:
-            eclass_dir = pjoin(namespace.repo.location, 'eclass')
+            eclass_dir = pjoin(namespace.repo.location, "eclass")
             try:
                 files = sorted(os.listdir(eclass_dir))
             except FileNotFoundError:
                 files = []
-            eclasses = [pjoin(eclass_dir, x) for x in files if x.endswith('.eclass')]
+            eclasses = [pjoin(eclass_dir, x) for x in files if x.endswith(".eclass")]
             if not eclasses:
-                parser.error(f'{namespace.repo.repo_id} repo: no eclasses found')
+                parser.error(f"{namespace.repo.repo_id} repo: no eclasses found")
 
         setattr(namespace, self.dest, eclasses)
 
 
 eclass = subparsers.add_parser(
-    "eclass", parents=shared_options_domain,
-    description="generate eclass docs")
+    "eclass", parents=shared_options_domain, description="generate eclass docs"
+)
 eclass.add_argument(
-    'eclasses', nargs='*', help="eclasses to target",
-    action=arghparse.Delayed, target=EclassArgs, priority=1001)
+    "eclasses",
+    nargs="*",
+    help="eclasses to target",
+    action=arghparse.Delayed,
+    target=EclassArgs,
+    priority=1001,
+)
 eclass_opts = eclass.add_argument_group("subcommand options")
 eclass_opts.add_argument(
-    "--dir", dest='output_dir', type=arghparse.create_dir, help="output directory")
+    "--dir", dest="output_dir", type=arghparse.create_dir, help="output directory"
+)
 eclass_opts.add_argument(
-    "-f", "--format", help="output format",
-    default='man', choices=('rst', 'man', 'html'))
+    "-f",
+    "--format",
+    help="output format",
+    default="man",
+    choices=("rst", "man", "html"),
+)
 eclass_opts.add_argument(
-    "-r", "--repo", help="target repository",
-    action=commandline.StoreRepoObject, repo_type='ebuild-raw', allow_external_repos=True,
+    "-r",
+    "--repo",
+    help="target repository",
+    action=commandline.StoreRepoObject,
+    repo_type="ebuild-raw",
+    allow_external_repos=True,
     docs="""
         Target repository to search for eclasses. If no repo is specified the default repo is used.
-    """)
+    """,
+)
 
 
-@eclass.bind_delayed_default(1000, 'repo')
+@eclass.bind_delayed_default(1000, "repo")
 def _eclass_default_repo(namespace, attr):
     """Use default repo if none is selected."""
-    repo = namespace.config.get_default('repo')
+    repo = namespace.config.get_default("repo")
     setattr(namespace, attr, repo)
 
 
-@eclass.bind_delayed_default(1000, 'output_dir')
+@eclass.bind_delayed_default(1000, "output_dir")
 def _eclass_default_output_dir(namespace, attr):
     """Use CWD as output dir if unset."""
     setattr(namespace, attr, os.getcwd())
@@ -418,25 +532,27 @@ def _eclass_default_output_dir(namespace, attr):
 @eclass.bind_main_func
 def _eclass_main(options, out, err):
     # suppress all eclassdoc parsing warnings
-    logging.getLogger('pkgcore').setLevel(100)
+    logging.getLogger("pkgcore").setLevel(100)
     failed = []
 
     # determine output file extension
-    ext_map = {'man': '5'}
+    ext_map = {"man": "5"}
     ext = ext_map.get(options.format, options.format)
 
     for path in options.eclasses:
         try:
-            with open(pjoin(options.output_dir, f'{os.path.basename(path)}.{ext}'), 'wt') as f:
+            with open(
+                pjoin(options.output_dir, f"{os.path.basename(path)}.{ext}"), "wt"
+            ) as f:
                 obj = EclassDoc(path)
-                convert_func = getattr(obj, f'to_{options.format}')
+                convert_func = getattr(obj, f"to_{options.format}")
                 f.write(convert_func())
         except ValueError as e:
             # skip eclasses lacking eclassdoc support
-            err.write(f'{eclass.prog}: skipping {path!r}: {e}')
+            err.write(f"{eclass.prog}: skipping {path!r}: {e}")
             err.flush()
         except IOError as e:
-            err.write(f'{eclass.prog}: error: {path!r}: {e}')
+            err.write(f"{eclass.prog}: error: {path!r}: {e}")
             err.flush()
             failed.append(path)
 
