@@ -31,13 +31,18 @@ class tree(prototype.tree):
     operations_kls = repo_ops.operations
 
     pkgcore_config_type = ConfigHint(
-        {'location': 'str',
-         'cache_location': 'str', 'repo_id': 'str',
-         'disable_cache': 'bool'},
-        typename='repo')
+        {
+            "location": "str",
+            "cache_location": "str",
+            "repo_id": "str",
+            "disable_cache": "bool",
+        },
+        typename="repo",
+    )
 
-    def __init__(self, location, cache_location=None, repo_id='vdb',
-                 disable_cache=False):
+    def __init__(
+        self, location, cache_location=None, repo_id="vdb", disable_cache=False
+    ):
         super().__init__(frozen=False)
         self.repo_id = repo_id
         self.location = location
@@ -50,15 +55,17 @@ class tree(prototype.tree):
         try:
             st = os.stat(self.location)
             if not stat.S_ISDIR(st.st_mode):
-                raise errors.InitializationError(
-                    f"base not a dir: {self.location!r}")
+                raise errors.InitializationError(f"base not a dir: {self.location!r}")
             elif not st.st_mode & (os.X_OK | os.R_OK):
                 raise errors.InitializationError(
-                    f"base lacks read/executable: {self.location!r}")
+                    f"base lacks read/executable: {self.location!r}"
+                )
         except FileNotFoundError:
             pass
         except OSError as e:
-            raise errors.InitializationError(f'lstat failed on base: {self.location!r}') from e
+            raise errors.InitializationError(
+                f"lstat failed on base: {self.location!r}"
+            ) from e
 
         self.package_class = self.package_factory(self)
 
@@ -71,8 +78,9 @@ class tree(prototype.tree):
             return {}
         try:
             try:
-                return tuple(x for x in listdir_dirs(self.location) if not
-                             x.startswith('.'))
+                return tuple(
+                    x for x in listdir_dirs(self.location) if not x.startswith(".")
+                )
             except EnvironmentError as e:
                 raise KeyError(f"failed fetching categories: {e}") from e
         finally:
@@ -85,36 +93,43 @@ class tree(prototype.tree):
         bad = False
         try:
             for x in listdir_dirs(cpath):
-                if x.startswith(".tmp.") or x.endswith(".lockfile") \
-                        or x.startswith("-MERGING-"):
+                if (
+                    x.startswith(".tmp.")
+                    or x.endswith(".lockfile")
+                    or x.startswith("-MERGING-")
+                ):
                     continue
                 try:
-                    pkg = VersionedCPV(f'{category}/{x}')
+                    pkg = VersionedCPV(f"{category}/{x}")
                 except InvalidCPV:
                     bad = True
                 if bad or not pkg.fullver:
-                    if '-scm' in x:
-                        bad = 'scm'
-                    elif '-try' in x:
-                        bad = 'try'
+                    if "-scm" in x:
+                        bad = "scm"
+                    elif "-try" in x:
+                        bad = "try"
                     else:
-                        raise InvalidCPV(f'{category}/{x}', 'no version component')
+                        raise InvalidCPV(f"{category}/{x}", "no version component")
                     logger.error(
-                        f'merged -{bad} pkg detected: {category}/{x}. '
-                        f'throwing exception due to -{bad} not being a valid'
-                        ' version component.  Silently ignoring that '
-                        'specific version is not viable either since it '
-                        'would result in pkgcore stomping whatever it was '
-                        f'that -{bad} version merged.  '
-                        'Use the offending pkg manager that merged it to '
-                        'unmerge it.')
+                        f"merged -{bad} pkg detected: {category}/{x}. "
+                        f"throwing exception due to -{bad} not being a valid"
+                        " version component.  Silently ignoring that "
+                        "specific version is not viable either since it "
+                        "would result in pkgcore stomping whatever it was "
+                        f"that -{bad} version merged.  "
+                        "Use the offending pkg manager that merged it to "
+                        "unmerge it."
+                    )
                     raise InvalidCPV(
-                        f'{category}/{x}', f'{bad} version component is not standard.')
+                        f"{category}/{x}", f"{bad} version component is not standard."
+                    )
                 l.add(pkg.package)
                 d.setdefault((category, pkg.package), []).append(pkg.fullver)
         except EnvironmentError as e:
             category = pjoin(self.location, category.lstrip(os.path.sep))
-            raise KeyError(f'failed fetching packages for category {category}: {e}') from e
+            raise KeyError(
+                f"failed fetching packages for category {category}: {e}"
+            ) from e
 
         self._versions_tmp_cache.update(d)
         return tuple(l)
@@ -131,17 +146,25 @@ class tree(prototype.tree):
         return pjoin(self.location, pkg.category, s)
 
     _metadata_rewrites = {
-        "bdepend": "BDEPEND", "depend": "DEPEND", "rdepend": "RDEPEND", "pdepend": "PDEPEND",
+        "bdepend": "BDEPEND",
+        "depend": "DEPEND",
+        "rdepend": "RDEPEND",
+        "pdepend": "PDEPEND",
         "idepend": "IDEPEND",
-        "use": "USE", "eapi": "EAPI", "CONTENTS": "contents",
-        "source_repository": "repository", "fullslot": "SLOT",
+        "use": "USE",
+        "eapi": "EAPI",
+        "CONTENTS": "contents",
+        "source_repository": "repository",
+        "fullslot": "SLOT",
     }
 
     def _get_metadata(self, pkg):
         return IndeterminantDict(
-            partial(self._internal_load_key, pjoin(
-                self.location, pkg.category,
-                f"{pkg.package}-{pkg.fullver}")))
+            partial(
+                self._internal_load_key,
+                pjoin(self.location, pkg.category, f"{pkg.package}-{pkg.fullver}"),
+            )
+        )
 
     def _internal_load_key(self, path, key):
         key = self._metadata_rewrites.get(key, key)
@@ -149,28 +172,28 @@ class tree(prototype.tree):
             data = ContentsFile(pjoin(path, "CONTENTS"), mutable=True)
         elif key == "environment":
             fp = pjoin(path, key)
-            if not os.path.exists(f'{fp}.bz2'):
+            if not os.path.exists(f"{fp}.bz2"):
                 if not os.path.exists(fp):
                     # icky.
                     raise KeyError("environment: no environment file found")
                 data = data_source.local_source(fp)
             else:
-                data = data_source.bz2_source(f'{fp}.bz2')
-        elif key == 'ebuild':
-            fp = pjoin(path, os.path.basename(path.rstrip(os.path.sep)) + '.ebuild')
+                data = data_source.bz2_source(f"{fp}.bz2")
+        elif key == "ebuild":
+            fp = pjoin(path, os.path.basename(path.rstrip(os.path.sep)) + ".ebuild")
             data = data_source.local_source(fp)
-        elif key == 'repo':
+        elif key == "repo":
             # try both, for portage/paludis compatibility.
-            data = readfile(pjoin(path, 'repository'), True)
+            data = readfile(pjoin(path, "repository"), True)
             if data is None:
-                data = readfile(pjoin(path, 'REPOSITORY'), True)
+                data = readfile(pjoin(path, "REPOSITORY"), True)
                 if data is None:
                     raise KeyError(key)
         else:
             data = readfile(pjoin(path, key), True)
             if data is None:
                 raise KeyError((path, key))
-            data = data.rstrip('\n')
+            data = data.rstrip("\n")
         return data
 
     def notify_remove_package(self, pkg):
@@ -200,8 +223,8 @@ class _WrappedInstalledPkg(pkg_base.wrapper):
 
     def __str__(self):
         return (
-            f'installed pkg: {self.cpvstr}::{self.repo.repo_id}, '
-            f'source repo {self.source_repository!r}'
+            f"installed pkg: {self.cpvstr}::{self.repo.repo_id}, "
+            f"source repo {self.source_repository!r}"
         )
 
 
@@ -221,4 +244,5 @@ class ConfiguredTree(wrapper.tree, tree):
     def _generate_operations(self, domain, pkg, **kwargs):
         pkg = pkg._raw_pkg
         return ebd.built_operations(
-            domain, pkg, initial_env=self.domain_settings, **kwargs)
+            domain, pkg, initial_env=self.domain_settings, **kwargs
+        )
