@@ -7,7 +7,7 @@ from .test_choice_point import fake_package
 
 class fake_blocker(restriction.base):
 
-    __slots__ = ('key', 'blocks')
+    __slots__ = ("key", "blocks")
 
     def __init__(self, key, blocks=()):
         restriction.base.__init__(self)
@@ -24,7 +24,6 @@ class fake_blocker(restriction.base):
 
 
 class TestSlot:
-
     def test_add(self):
         c = PigeonHoledSlots()
         o = fake_package()
